﻿using System;
namespace HDL_ON.Entity
{
   

    /// <summary>
    /// 操作码
    /// </summary>
    public enum Command
    {
        /// <summary>
        /// 读取模拟量值
        /// </summary>
        ReadAnalog = 0xE50A,
        ReadAnalogACK = 0xE50B,

        #region 绿建温控器协议
        /// <summary>
        /// 读取温控器主机指令
        /// 发送
        /// 1   通道号 1-255
        /// 回复
        /// 1   通道号 
        /// 2   开/关机    0--关 1--开
        /// 3   运行模式    1-制冷，2-制热，3-通风，4-除湿，5-制热除湿
        /// 4   运行场景    1-在家，2-离家，3-睡眠
        /// 5   湿度档位    1-低，2-中，3-高（只在制热模式下可以设置）
        /// 6   滤网百分比   %
        /// 7   温控器分机数量 1-32
        /// 8-9 故障信息1   
        /// 10-11   故障信息2   
        /// 12-13   故障信息3   
        /// 14-15   故障信息4   
        /// 16-17   故障信息5   
        /// 18-19   故障信息6   
        /// 20-21   模拟量激活位  从低位开始，如enable[0] 的bit0--->室内温度
        /// 22-25   模拟量1（bit0）室内温度  浮点型数据 IEEE 754浮点数
        /// 26-29   模拟量2（bit1）室内湿度  浮点型数据 0-100 % IEEE 754浮点数
        /// 30-33   模拟量3（bit2）室内CO2 浮点型数据 PPM IEEE 754浮点数
        /// 34-37   模拟量4（bit3）室内TVOC    浮点型数据 级 IEEE 754浮点数
        /// 38-41   模拟量5（bit4）室内PM2.5   浮点型数据 PPM IEEE 754浮点数
        /// 42-45   模拟量6（bit5）室外温度  浮点型数据 IEEE 754浮点数
        /// 46-49   模拟量7（bit6）室外湿度  浮点型数据 0-100 % IEEE 754浮点数
        /// 50-53   模拟量8（bit7）室外PM2.5   浮点型数据 PPM IEEE 754浮点数
        /// </summary>
        ReadThermostatHost = 0x8099,
        ReadThermostatHostACK = 0x809A,

        /// <summary>
        /// 控制温控器主机指令
        /// 发送
        /// 1   通道号 
        /// 2   开/关机    0--关 1--开
        /// 3   运行模式    1-制冷，2-制热，3-通风，4-除湿，5-制热除湿
        /// 4   运行场景    1-在家，2-离家，3-睡眠
        /// 5   湿度档位    1-低，2-中，3-高（只在制热模式下可以设置）
        /// 回复
        /// 1   通道号 
        /// 2   开/关机    0--关 1--开
        /// 3   运行模式    1-制冷，2-制热，3-通风，4-除湿，5-制热除湿
        /// 4   运行场景    1-在家，2-离家，3-睡眠
        /// 5   湿度档位    1-低，2-中，3-高（只在制热模式下可以设置）
        /// 6   滤网百分比   %
        /// 7   温控器分机数量 1-32
        /// 8-9 故障信息1   
        /// 10-11   故障信息2   
        /// 12-13   故障信息3   
        /// 14-15   故障信息4   
        /// 16-17   故障信息5   
        /// 18-19   故障信息6   
        /// 20-21   模拟量激活位  从低位开始，如enable[0] 的bit0--->室内温度
        /// 22-25   模拟量1（bit0）室内温度  浮点型数据 IEEE 754浮点数
        /// 26-29   模拟量2（bit1）室内湿度  浮点型数据 0-100 % IEEE 754浮点数
        /// 30-33   模拟量3（bit2）室内CO2 浮点型数据 PPM IEEE 754浮点数
        /// 34-37   模拟量4（bit3）室内TVOC    浮点型数据 级 IEEE 754浮点数
        /// 38-41   模拟量5（bit4）室内PM2.5   浮点型数据 PPM IEEE 754浮点数
        /// 42-45   模拟量6（bit5）室外温度  浮点型数据 IEEE 754浮点数
        /// 46-49   模拟量7（bit6）室外湿度  浮点型数据 0-100 % IEEE 754浮点数
        /// 50-53   模拟量8（bit7）室外PM2.5   浮点型数据 PPM IEEE 754浮点数
        /// </summary>
        SetThermostatHost = 0x809B,
        SetThermostatHostACK = 0x809C,


        /// <summary>
        /// 读取温控器分机指令
        /// 发送
        /// 1   通道号 1-255
        /// 回复
        /// 1   通道号 1-255
        /// 2   温控器开/关机 0-关机，1-开机
        /// 3   模拟量激活位  从低位开始 如bit0对应温控器环境温度值
        /// 4-7 温控器环境温度值    浮点型数据  ℃ IEEE 754浮点数
        /// 8-11    温控器设置温度值    浮点型数据  ℃ IEEE 754浮点数
        /// 12-15   温控器环境湿度值    浮点型数据   % IEEE 754浮点数
        /// 16-19   温控器设置湿度值    浮点型数据   % IEEE 754浮点数
        /// </summary>
        ReadThermostatExtension = 0x809D,
        ReadThermostatExtensionACK = 0x809E,


        /// <summary>
        /// 控制温控器分机指令
        /// 发送
        /// 1   通道号 1-255
        /// 2   温控器分机开/关机   0-关机，1-开机
        /// 3   模拟量激活位  从低位开始 如bit0对应温控器环境温度值
        /// 4-7 温控器分机设置温度值  浮点型数据  ℃ IEEE 754浮点数
        /// 8-11    温控器分机湿度值    浮点型数据   % IEEE 754浮点数
        /// 回复
        /// 1   通道号 1-255
        /// 2   温控器开/关机 0-关机，1-开机
        /// 3   模拟量激活位  从低位开始 如bit0对应温控器环境温度值
        /// 4-7 温控器环境温度值    浮点型数据  ℃ IEEE 754浮点数
        /// 8-11    温控器设置温度值    浮点型数据  ℃ IEEE 754浮点数
        /// 12-15   温控器环境湿度值    浮点型数据   % IEEE 754浮点数
        /// 16-19   温控器设置湿度值    浮点型数据   % IEEE 754浮点数
        /// </summary>
        SetThermostatExtension = 0x809F,
        SetThermostatExtensionACK = 0x80A0,

        #endregion
        /// <summary>
        /// 读取面板温度类型  
        /// </summary>
        ReadPanelTempType = 0xE120,
        ReadPanelTempTypeACK = 0xE121,

        #region 毅面板协议
        YIPanelName = 0x0010,
        YIPanelDevice = 0x2F06,
        YIPanelDeviceProperty = 0x2F00,
        YIPanelDeviceInof = 0x2F02,
        YIPanelDeviceInofACK = 0x2F03,

        YIPanelDeviceModify = 0x2F04,
        YIPanelDeviceModifyACK = 0x2F05,
        #endregion

        #region DALI CCT 控制
        //==================单路色温调节=========================//20190307
        Adjust_lamp_color_Temperature = 0x19DE,
        //[0]//灯号    1-64                                        1BYTE
        //[1]1色温调冷，2色温调暖，                              1BYTE
        Adjust_lamp_color_Temperature_ack = 0x19DF,      //广播
        //[0]//灯号    1-64                                        1BYTE
        //[1]1色温调冷，2色温调暖，                              1BYTE
        //==================单路色温控制=========================//20190307
        read_lamp_color_Temperature = 0x19E0,
        //[0]//灯号    1-64                                        1BYTE
        read_lamp_color_Temperature_ack = 0x19E1,
        //[0]//灯号    1-64                                        1BYTE
        //[1][2]//色温值高BYTE+色温值低BYTE     0-0xFFFF         2BYTE
        control_lamp_color_Temperature = 0x19E2,
        //[0]//灯号    1-64                                        1BYTE
        //[1][2]//色温值高BYTE+色温值低BYTE     0-0xFFFF         2BYTE
        control_lamp_color_Temperature_ack = 0x19E3,     //广播
        //[0]//灯号    1-64                                        1BYTE
        //[1][2]//色温值高BYTE+色温值低BYTE     0-0xFFFF         2BYTE
        #endregion

        #region 豪恩传感器协议

        /// <summary>
        /// 修改通道备
        /// 1   物理通道号   1-32（其他物理通道号无效）
        /// 2   物理通道号备注第1个byte  0-255
        /// 3-20    ... 0-255
        /// 21  物理通道号备注第20个byte 0-255
        /// </summary>
        UpdateHornLoopRemake = 0x1F6C,
        /// <summary>
        /// 1   成功或失败   0xF8或0xF5
        /// 2   物理通道号   1-32（其他物理通道号无效）
        /// </summary>
        UpdateHornLoopRemakeACK = 0x1F6D,

        /// <summary>
        /// 读取开、关、拆低电量对应的受控目标配置
        /// 1   动作类型    1-128，设备1-32每个有4种关0、开1、拆2、低电量3分别对用20个受控目标
        ///     例如传感器物理通道是1-32，但是物理通道1的传感器关的目标编号是1，开的是2，拆的是3，物理通道2的传感器关的目标编号是4，开的是5，拆的是6
        /// 2   目标序号    1-20
        /// </summary>
        ReadHornTargetState = 0xE414,
        /// <summary>
        /// 1   回复成功,或失败    0xF8或0xF5
        /// 2   动作类型    1-128，设备1-32每个有4种开、关、拆、低电量分别对用20个受控目标
        /// 3   目标序号    1-20
        /// 4   类型  无效0、
        /// 5   子网ID    
        /// 6   设备ID    
        /// 7   参数一 
        /// 8   参数二 
        /// 9   参数三 
        /// 10  参数四
        /// </summary>
        ReadHornTargetStateACK = 0xE415,
        /// <summary>
        /// 修改开、关、拆、低电量对应的受控目标配置（0xE416）
        /// 操作码: 0x E416
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:9
        /// 编号  备注  值域
        /// 1   动作类型    1-128，设备1-32每个有4种开、关、拆、低电量分别对用20个受控目标
        /// 2   目标序号    1-20
        /// 3   类型  无效0、
        /// 4   子网ID    
        /// 5   设备ID    
        /// 6   参数一 
        /// 7   参数二 
        /// 8   参数三 
        /// 9   参数四
        /// </summary>
        SetHornTargetState = 0xE416,
        /// <summary>
        /// ACK修改开、关、拆、低电量对应的受控目标配置（0xE417）
        /// 操作码: 0x E417
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:3
        /// 编号  备注  值域
        /// 1   回复成功, 或失败    0xF8或0xF5
        /// 2   动作类型    1-128，设备1-32每个有4种开、关、拆、低电量分别对用20个受控目标
        /// 3   目标序号    1-20
        /// </summary>
        SetHornTargetStateACK = 0xE416,

        /// <summary>
        /// 读目标使能配置
        /// 操作码: 0x3571
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:2
        /// 编号  备注  值域
        /// 1   动作类型    设备0-31 / 255 返回全部 32 回路的使能设置，共32 字节
        /// </summary>
        ReadHornTargetEnable = 0x3571,
        /// <summary>
        /// 读目标使能配置返回
        /// 操作码: 0x3572
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:2
        /// 编号  备注  值域
        /// 1   动作类型    设备0-31 / 255 返回全部 32 回路的使能设置，共32 字节
        /// 2   使能  0：disabled    1：enable
        /// </summary>
        ReadHornTargetEnableACK = 0x3572,

        /// <summary>
        /// 写目标使能配置
        /// 操作码: 0x356f
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:2
        /// 编号  备注  值域
        /// 1   动作类型    设备0-31 
        /// 2   使能  0：disabled    1：enable
        /// </summary>
        SetHornTargetEnable = 0x356f,
        /// <summary>
        /// 写目标使能配置返回
        /// 操作码: 0x3570
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:2
        /// 编号  备注  值域
        /// 1   动作类型    设备0-31 
        /// 2   回复成功, 或失败    0xF8或0xF5
        /// </summary>
        SetHornTargetEnableACK = 0x3570,

        /// <summary>
        /// 设备状态广播（0x15D0）
        /// 操作码: 0x15D0
        /// 通讯方式: 广播
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:6
        /// 编号  备注  值域
        /// 1   区号  0-254
        /// 2   物理通道号   1-32（其他物理通道号无效）
        /// 3   传感器状态   关0，开1，拆2 ，低电量3，心跳4(4小时内没心跳就离线了)
        /// 4   大类别 0-255
        /// 5   小类别 0-255
        /// 6   逻辑通道号   1-32（其他通道号无效），按物理通道号排序，每次注册、删除都会重新排序
        /// </summary>
        //HornStateBroadcast = 0x15D0,

        /// <summary>
        /// 设备报警广播（0xF606）
        /// 操作码: 0xF606
        /// 通讯方式: 广播
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:7
        /// 编号  备注  值域
        /// 1   区号  0-254
        /// 2   物理通道号   1-32（其他物理通道号无效）
        /// 3   报警类型高字节 0-255
        /// 4   报警类型低字节 0-255
        /// 5   大类别 0-255
        /// 6   小类别 0-255
        /// 7   逻辑通道号   1-32（其他通道号无效），按物理通道号排序，每次注册、删除都会重新排序
        /// ----------------------
        /// 报警类型表
        /// 编号  报警分类    说明  备注
        /// 1   开关报警    门、窗、柜子、抽屉、保险柜   　
        /// 2   闯入报警    人体移动、电子栅栏   人体移动算一个状态，对于是否报警要看应用场景
        /// 3   温度过高报警  　   　
        /// 4   温度过低报警  　   　
        /// 5   湿度过低报警  　   　
        /// 6   湿度过高报警  　   　
        /// 7   高压报警（电压）    　   　
        /// 8   低压报警（电压）    　   　
        /// 9   过载报警（电流）    暂定过载主要是电流过载 　
        /// 10  水压过高    　   　
        /// 11  水压过低    　   　
        /// 12  液位超限    　   　
        /// 13  液位过低    　   　
        /// 14  漏水报警    　   　
        /// 15  PM2.5超限 　   　
        /// 16  PM10超限  　   　
        /// 17  紧急报警    紧急求助等   　
        /// 18  玻璃破碎报警  　   　
        /// 19  CO报警    　   　
        /// 20  燃气报警    石油液化气、天然气、煤气等都可以使用燃气报警  　
        /// 21  火灾报警    　   　
        /// 22  烟雾报警    　   　
        /// 23  劫持报警    　   　
        /// 24  密码错误警告  门锁、APK等 　
        /// 25  防拆、防撬报警 部分传感器、门锁等   　
        /// 26  指纹错误报警  　   
        /// 27  门未锁好       状态/报警推送
        /// 28  电量不足状态  电池设备电量过低    电量不足状态/报警推送
        /// </summary>
        HornAlarmBroadcast = 0xF606,

        /// <summary>
        /// 使能通道报警
        /// 操作码: 0xE01C
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:2
        /// 编号  备注  值域
        /// 1   物理通道号   1-32（其他物理通道号无效）
        /// 2   是否使能    255为使能，0为禁止
        /// </summary>
        //SetHornLoopAlarm = 0xE01C,
        /// <summary>
        /// ACK使能通道报警（0xE01D）
        /// 操作码: 0xE01D
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:2
        /// 编号  备注  值域
        /// 1   物理通道号   1-32（其他物理通道号无效）
        /// 2   是否使能    255为使能，0为禁止
        /// </summary>
        //SetHornLoopAlarmACK = 0xE01D,

        /// <summary>
        /// 读取此通道是否使能报警（0xE018）
        /// 操作码: 0xE018
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254  SetHornLoopAlarm
        /// 附加数据内容
        /// 附加数据长度:1
        /// 编号  备注  值域
        /// 1   物理通道号   1-32（其他物理通道号无效）
        /// </summary>
        ReadHornLoopAlarm = 0xE018,
        /// <summary>
        /// ACK读取此通道是否使能报警（0xE019）
        /// 操作码: 0xE019
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:2
        /// 编号  备注  值域
        /// 1   物理通道号   1-32（其他物理通道号无效）
        /// 2   是否使能    255为使能，0为禁止
        /// </summary>
        ReadHornLoopAlarmACK = 0xE019,

        /// <summary>
        /// 5.1 推送信息设置  
        /// 操作码: 0x3569
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:6
        /// 编号  备注  值域
        /// 1   物理通道号   0~31
        /// 2   预留  预留
        /// 3   使能设置    1：enable        0:disable
        /// 4   子网ID    1 byte
        /// 5   设备ID    1 byte
        /// </summary>
        SetHornPush = 0x3569,
        /// <summary>
        /// 5.2 推送信息设置返回    
        /// 操作码: 0x356a
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:3
        /// 编号  备注  值域
        /// 1   物理通道号   0~31
        /// 2   预留  预留
        /// 3   Status  F8 / F5
        /// </summary>
        SetHornPushACK = 0x356A,

        /// <summary>
        /// 5.3 读推送信息设置 
        /// 操作码: 0x356b
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:2
        /// 编号  备注  值域
        /// 1   物理通道号   0~31
        /// 2   预留  预留
        /// </summary>
        ReadHornPush = 0x356b,
        /// <summary>
        /// 5.4 读推送信息设置返回   
        /// 操作码: 0x356c
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:5
        /// 编号  备注  值域
        /// 1   物理通道号   0~31
        /// 2   预留  预留
        /// 3   使能设置    1：enable        0:disable
        /// 4   子网ID    1 byte
        /// 5   设备ID    1 byte
        /// </summary>
        ReadHornPushACK = 0x356C,

        /// <summary>
        /// 6.1 读取动作历史  
        /// 操作码: 0x356d
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:2
        /// 编号  备注  值域
        /// 1   记录序号    0~99共百条 / 255：返回全部
        /// </summary>
        ReadHornHistory = 0x356d,
        /// <summary>
        /// 6.2读取动作历史返回 
        /// 操作码: 0x356e
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:8
        /// 编号  备注  值域
        /// 1   记录序号    0~99共百条
        /// 2   物理通道号   0~31
        /// 3   动作类别    关0，开1，拆2 ，低电量3
        /// 4   年   范围：公元年与2000的差
        /// 5   月   0 - 11
        /// 6   日   0 - 30
        /// 7   时   0 - 23
        /// 8   分   0 - 59 
        /// </summary>
        ReadHornHistoryACK = 0x356e,

        /// <summary>
        /// The read horn loop count.
        /// </summary>
        ReadHornLoopCount = 0xE510,
        /// <summary>
        /// 回复设备总数
        /// </summary>
        ReadHornLoopCountACK = 0xE511,

        /// <summary>
        /// 读取设备状态情况
        /// 操作码:0xE512
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容 :3
        /// 附加数据长度: 
        /// 编号  备注  值域
        /// 1   设备总数    1-N
        /// 2   开始读取设备地址    1-N
        /// 3   读取多少个   1-16
        /// </summary>
        ReadHornLoopsStatus = 0xE512,
        /// <summary>
        /// 依次读取设备状态情况返回
        /// 操作码:0xE513
        /// 通讯方式: 广播
        /// 子网ID范围:255  设备ID范围: 255
        /// 附加数据内容 :3 + N * 4（N设备总数）
        /// 附加数据长度: 
        /// 编号  备注  值域
        /// 1   设备总数    1-N
        /// 2   开始读取设备地址    1-N
        /// 3   读取多少个   1-16
        /// 4   第一个设备大类 
        /// 5   第一个设备小类 
        /// 6   第一个设备通道号    
        /// 7   第一个设备状态 0：离线，其他预留 1：在线
        /// 8   第二个设备大类 
        /// 9   第二个设备小类 
        /// 10  第二个设备通道号    
        /// ... 第二个设备状态 0：离线，其他预留 1：在线
        /// </summary>
        ReadHornLoopsStatusACK = 0xE513,
        #endregion

        #region 海客传感器协议
        /// <summary>
        ///  2.1设置目标组备注
        /// 操作码: 0x3532
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:22
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5        0
        ///     2.CO2浓度      1
        ///     3.TVOC浓度     2
        ///     4.  温度        3
        ///     5.  湿度        4
        ///     2   Level   Level: 0 ~ 7 每一级别对应下面的组备注
        /// 3   传感器目标组备注0   0 ~ 255
        /// 22  传感器目标组备注19  0 ~ 255
        /// </summary>
        SetSensorTargetRemark = 0x3532,
        /// <summary>
        /// 1   存储状态    0xf8 / 0xf5 /0xf1 存储失败
        /// </summary>
        SetSensorTargetRemarkACK = 0x3533,

        /// <summary>
        /// 2.3读取目标组备注
        /// 操作码: 0x3534
        /// 附加数据长度:2
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5     0
        ///     2.CO2浓度     1
        ///     3.TVOC浓度    2
        ///     4.  温度      3
        ///     5.  湿度      4
        /// 2   Level   Level: 0 ~ 7 每一级别对应下面的组备注
        /// </summary>
        ReadSensorTargetRemark = 0x3534,
        /// <summary>
        /// 2.4读取目标组备注
        /// 操作码: 0x3535
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5        0
        ///     2.CO2浓度      1
        ///     3.TVOC浓度     2
        ///     4.  温度        3
        ///     5.  湿度        4
        ///     2   Level   Level: 0 ~ 7 每一级别对应下面的组备注
        /// 3   传感器目标组备注0   0 ~ 255
        /// 22  传感器目标组备注19  0 ~ 255
        /// </summary>
        ReadSensorTargetRemarkACK = 0x3535,
        /// <summary>
        /// 6.3 读取目标设置  
        /// 操作码: 0x3543
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:3
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5        0
        ///     2.CO2浓度      1
        ///     3.TVOC浓度     2
        ///     4.温度         3
        ///     5.湿度         4
        /// 2   目标级别    Level: 0 ~ 7 每一级别对不同的组范围
        /// 3   目标序号    number 0~19
        /// </summary>
        ReadSensorScence = 0x3543,
        /// <summary>
        /// 6.4 读取目标设置返回    
        /// 操作码: 0x3544
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:10
        /// 编号  备注  值域
        /// 1   类型  
        ///     1   PM2.5       0
        ///     2   CO2浓度      1
        ///     3   TVOC浓度     2
        ///     4   温度         3
        ///     5   湿度         4
        /// 2   目标级别    Level: 0 ~ 7 每一级别对不同的组范围
        /// 3   目标序号    number 0~19
        /// 4   　       Control_kind  控制类型             
        /// 5   　       Control_sub_net   子网号         
        /// 6   　       Control_dev          设备号      
        /// 7   　       Control_fenqu           回路号   
        /// 8   　       Control_changjing          
        /// 9   　       Control_minute—singal_adj 
        /// 10  　       Control_second—singal_adj
        /// </summary>
        ReadSensorScenceACK = 0x3544,
        /// <summary>
        /// 6.4 读取目标设置返回    
        /// 操作码: 0x3541
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:10
        /// 编号  备注  值域
        /// 1   类型  
        ///     1   PM2.5        0
        ///     2   CO2浓度      1
        ///     3   TVOC浓度     2
        ///     4   温度         3
        ///     5   湿度         4
        /// 2   目标级别    Level: 0 ~ 7 每一级别对不同的组范围
        /// 3   目标序号    number 0~19
        /// 4   　       Control_kind               
        /// 5   　       Control_sub_net            
        /// 6   　       Control_dev                
        /// 7   　       Control_fenqu              
        /// 8   　       Control_changjing          
        /// 9   　       Control_minute—singal_adj 
        /// 10  　       Control_second—singal_adj
        /// </summary>
        SetSensorScence = 0x3541,
        /// <summary>
        /// 6.3 读取目标设置  
        /// 操作码: 0x3542
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:3
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5        0
        ///     2.CO2浓度      1
        ///     3.TVOC浓度     2
        ///     4.温度         3
        ///     5.湿度         4
        /// 2   目标级别    Level: 0 ~ 7 每一级别对不同的组范围
        /// 3   目标序号    number 0~19
        /// </summary>
        SetSensorScenceACK = 0x3542,



        /// <summary>
        /// 设置目标范围
        /// 附加数据长度:6
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5     0       ug/m3    范围 0～999ug/m3
        ///     2.CO2浓度    1        ppm      400～5000ppm
        ///     3.TVOC浓度   2        0.01mg/m3  0.22～9.99mg/m3
        ///     4.温度     3        0.1℃    范围 -40℃～125℃（负数为最高位置1）
        ///     5.湿度     4        0.1%RH  范围 0～100%RH 
        /// 2   级别  Level: 0 ~ 7 每一级别对应下面的组范围
        /// 3   左边界高位   
        /// 4   左边界低位   左范围要小于右边界
        /// 5   右边界高位   
        /// 6   右边界低位
        /// </summary>
        SetSensorPushValues = 0x3536,
        /// <summary>
        /// 设置目标范围返回
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:2
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5     0   ug/m3        范围 0～999ug/m3
        ///     2.CO2浓度    1    ppm         400～5000ppm
        ///     3.TVOC浓度   2    0.01mg/m3    0.22～9.99mg/m3
        ///     4.  温度     3     0.1℃      范围 -40℃～125℃（负数为最高位置1）
        ///     5.  湿度     4     0.1%RH    范围 0～100%RH 
        ///     0xf5 失败
        /// 2   级别  Level: 0 ~ 7 
        /// </summary>
        SetSensorPushValuesACK = 0x3537,
        /// <summary>
        /// 读取目标范围
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:2
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5       0   ug/m3        范围 0～999ug/m3
        ///     2.CO2浓度    1    ppm         400～5000ppm
        ///     3.TVOC浓度   2    0.01mg/m3    0.22～9.99mg/m3
        ///     4.  温度     3     0.1℃      范围 -40℃～125℃（负数为最高位置1）
        ///     5.  湿度     4     0.1%RH    范围 0～100%RH 
        /// 2   级别  Level: 0 ~ 7 
        /// </summary>
        ReadSensorPushValues = 0x3538,
        /// <summary>
        /// 读取目标范围返回
        /// 附加数据长度:6
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5     0       ug/m3    范围 0～999ug/m3
        ///     2.CO2浓度    1        ppm      400～5000ppm
        ///     3.TVOC浓度   2        0.01mg/m3  0.22～9.99mg/m3
        ///     4.  温度     3        0.1℃    范围 -40℃～125℃（负数为最高位置1）
        ///     5.  湿度     4        0.1%RH  范围 0～100%RH 
        ///     0xf5 失败
        /// 2   级别  Level: 0 ~ 7 每一级别对应下面的组范围
        /// 3   左边界高位   
        /// 4   左边界低位   左范围要小于右边界
        /// 5   右边界高位   
        /// 6   右边界低位
        /// </summary>
        ReadSensorPushValuesACK = 0x3539,

        /// <summary>
        /// 读取传感器历史曲线点
        /// 1   序号  传感器数据记录序号
        ///     1.   0~239   每 3 小时一次，每天 8 次，30天共240个点
        ///     2.   序号越小数据越新
        /// </summary>
        ReadSensorHistory = 0x353f,
        /// <summary>
        /// 读取传感器历史曲线点返回
        /// 附加数据长度:12
        /// 编号  备注  值域
        /// 1   序号  传感器数据记录序号
        ///     1.   0~239   每 3 小时一次，每天 8 次，30天共240个点
        ///     2.   序号越小数据越新
        ///     3. / 0xf5
        /// 2   PM2.5高位 ug/m3
        /// 3   PM2.5低位 ug/m3
        /// 4   CO2浓度高位 ppm
        /// 5   CO2浓度低位 ppm
        /// 6   TVOC浓度高位    0.01mg/m3
        /// 7   TVOC浓度低位    0.01mg/m3
        /// 8   温度  0.1℃
        /// 9   湿度  0.1%RH
        /// 10  月   0~11
        /// 11  日   0~30
        /// 12  时   0~23
        /// </summary>
        ReadSensorHistoryACK = 0x3540,

        /// <summary>
        /// 8.1 推送信息设置  
        /// 操作码: 0x3565
        /// 附加数据长度:6
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5        0
        ///     2.CO2浓度     1   
        ///     3.TVOC浓度    2
        ///     4.温度         3
        ///     5.湿度         4
        /// 2   通道号 预留，这里只有一个通道
        /// 3   目标级别    Level: 0 ~ 7 每一级别对不同的组范围
        /// 4   使能设置    1：enable        0:disable
        /// 5   子网ID    1 byte
        /// 6   设备ID    1 byte
        /// </summary>
        SetSensorPushMessage = 0x3565,
        /// <summary>
        /// 8.2 推送信息设置返回    
        /// 操作码: 0x3566
        /// 附加数据长度:4
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5        0
        ///     2.CO2浓度     1
        ///     3.TVOC浓度    2
        ///     4.温度         3
        ///     5.湿度         4
        /// 2   通道号 预留，这里只有一个通道
        /// 3   目标级别    Level: 0 ~ 7 每一级别对不同的组范围
        /// 4   Status  F8(success) / F5
        /// </summary>
        SetSensorPushMessageACK = 0x3566,
        /// <summary>
        /// 读推送信息
        /// 附加数据长度:3
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5        0
        ///     2.CO2浓度     1
        ///     3.TVOC浓度    2
        ///     4.温度         3
        ///     5.湿度         4
        /// 2   通道号 预留，这里只有一个通道
        /// 3   目标级别
        ///     Level: 0 ~ 7 每一级别对不同的组范围
        ///     注：当值为255时，返回8个等级的数据
        /// </summary>
        ReadSensorPushMessage = 0x3567,
        /// <summary>
        /// 8.4 读推送信息返回 
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5        0
        ///     2.CO2浓度     1
        ///     3.TVOC浓度    2
        ///     4.温度         3
        ///     5.湿度         4
        /// 2   通道号 预留，这里只有一个通道
        /// 3   目标级别    Level: 0 ~ 7 每一级别对不同的组范围
        ///     注：当值为255时，返回8个等级的数据
        ///     数据累加
        ///     使能位置，子网ID，设备ID
        /// 4   使能设置    1：enable        0:disable
        /// 5   子网ID    1 byte
        /// 6   设备ID    1 byte
        /// </summary>
        ReadSensorPushMessageACK = 0x3568,

        /// <summary>
        /// 9.3读取逻辑号使能设置    
        /// 操作码: 0x3575
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:0
        /// </summary>
        ReadSensorAutomationEnableList = 0x3575,
        /// <summary>
        /// 9.4读取逻辑号使能设置返回
        /// 操作码: 0x3576
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:40
        /// 编号  备注  值域
        /// 1   使能与启用   
        ///     0：delete；
        ///     1：enable；
        ///     2：unused
        /// ... ... ...
        /// 40  使能与启用   
        ///     0：delete；
        ///     1：enable；
        ///     2：unused
        /// </summary>
        ReadSensorAutomationEnableListACK = 0x3576,

        /// <summary>
        /// 9.1写逻辑号使能设置 
        /// 操作码: 0x3573
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:40
        /// 编号  备注  值域
        /// 1   使能与启用   
        ///     0：delete；
        ///     1：enable；
        ///     2：unused
        /// ... ... ...
        /// 40  使能与启用   
        ///     0：delete；
        ///     1：enable；
        ///     2：unused
        /// </summary>
        SetSensorAutomationEnableList = 0x3573,
        /// <summary>
        /// 附加数据长度: 1
        /// 编号  备注  值域
        /// 1   Status  0xf8 / 0xf5
        /// </summary>
        SetSensorAutomationEnableListACK = 0x3574,

        /// <summary>
        /// 10. 1写 ID设置
        /// 操作码: 0x3577
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:40
        /// 编号  备注  值域
        /// 1   ID  
        /// ... ... ...
        /// 40  ID  
        /// </summary>
        SetSensorAutomationListID = 0x3577,
        /// <summary>
        /// 10.2写 ID设置返回
        /// 操作码: 0x3578
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度: 1
        /// 编号  备注  值域
        /// 1   Status  0xf8 / 0xf5
        /// </summary>
        SetSensorAutomationListIDACK = 0x3578,

        /// <summary>
        /// 10.3读取ID设置
        /// 操作码: 0x3579
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:0
        /// 编号  备注  值域
        /// </summary>
        ReadSensorAutomationListID = 0x3579,
        /// <summary>
        /// 10.4读取ID设置返回
        /// 操作码: 0x357a
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:40
        /// 编号  备注  值域
        /// 1   ID  
        /// ... ... ...
        /// 40  ID
        /// </summary>
        ReadSensorAutomationListIDACK = 0x357a,

        /// <summary>
        /// 11. 1写 传感器类型条件使能 设置
        /// 操作码: 0x357b
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:4
        /// 编号  备注  值域
        /// 1   传感器类型   
        ///     1.PM2.5        0
        ///     2.CO2浓度     1
        ///     3.TVOC浓度    2
        ///     4.温度         3
        ///     5.湿度         4
        /// 2   第一级高位   Bit0:~Bit7     1:enable    0:disable
        /// 3   第一级中位   Bit0:~Bit7     1:enable    0:disable
        /// 4   第一级低位   Bit0:~Bit7     1:enable    0:disable
        /// ... ... ...
        /// 23  第八级高位   Bit0:~Bit7     1:enable    0:disable
        /// 24  第八级中位   Bit0:~Bit7     1:enable    0:disable
        /// 25  第八级低位   Bit0:~Bit7     1:enable    0:disable
        /// </summary>
        SetSensorAutomationTargetLevelEnable = 0x357b,
        /// <summary>
        /// 11.2写传感器类型条件使能 设置返回
        /// 操作码: 0x357c
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度: 2
        /// 编号  备注  值域
        /// 1   传感器类型   
        ///     1.PM2.5        0
        ///     2.CO2浓度     1
        ///     3.TVOC浓度    2
        ///     4.温度         3
        ///     5.湿度         4
        /// 2   Status  0xf8 / 0xf5
        /// </summary>
        SetSensorAutomationTargetLevelEnableACK = 0x357c,


        /// <summary>
        /// 11.3读取单条目标命令使能 设置
        /// 操作码: 0x357d
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:0
        /// 编号  备注  值域
        /// 1   传感器类型   
        ///     1.PM2.5        0
        ///     2.CO2浓度     1
        ///     3.TVOC浓度    2
        ///     4.温度         3
        ///     5.湿度         4
        /// </summary>
        ReadSensorAutomationLevelTargetEnable = 0x357d,
        /// <summary>
        /// 11.4读取单条目标命令使能 设置返回
        /// 操作码: 0x357e
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:40
        /// 编号  备注  值域
        /// 1   传感器类型   1.PM2.5        0
        /// 2.CO2浓度     1
        /// 3.TVOC浓度    2
        /// 4.温度         3
        /// 5.湿度         4
        /// 2   第一级高位   Bit0:~Bit7     1:enable    0:disable
        /// 3   第一级中位   Bit0:~Bit7     1:enable    0:disable
        /// 4   第一级低位   Bit0:~Bit7     1:enable    0:disable
        /// ... ... ...
        /// 23  第八级高位   Bit0:~Bit7     1:enable    0:disable
        /// 24  第八级中位   Bit0:~Bit7     1:enable    0:disable
        /// 25  第八级低位   Bit0:~Bit7     1:enable    0:disable
        /// </summary>
        ReadSensorAutomationLevelTargetEnableACK = 0x357e,


        /// <summary>
        /// 12. 1写高级逻辑备注设置
        /// 操作码: 0x357f
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:21
        /// 编号  备注  值域
        /// 1   序号  0 ~ 39
        /// 2   备注 1    
        /// 3   备注 2    
        /// ... ... ...
        /// 21  备注 20   
        /// </summary>
        SetSensorAutomationName = 0x357F,
        /// <summary>
        /// 12.2写高级逻辑备注设置返回
        /// 操作码: 0x3580
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度: 2
        /// 编号  备注  值域
        /// 1   序号  0 ~ 39
        /// 2   Status  0xf8 / 0xf5
        /// </summary>
        SetSensorAutomationNameACK = 0x3580,

        /// <summary>
        /// 12.3读高级逻辑备注 设置
        /// 操作码: 0x3581
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:1
        /// 编号  备注  值域
        /// 1   序号  0 ~ 39
        /// </summary>
        ReadSensorAutomationName = 0x3581,
        /// <summary>
        /// 12.4读高级逻辑备注设置返回
        /// 操作码: 0x3582
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:21
        /// 编号  备注  值域
        /// 1   序号  0 ~ 39
        /// 2   备注 1    
        /// 3   备注 2    
        /// ... ... ...
        /// 21  备注 20   
        /// </summary>
        ReadSensorAutomationNameACK = 0x3582,


        /// <summary>
        /// 7.1日历逻辑设置
        /// 操作码: 0x3561
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:16
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5        0
        ///     2.CO2浓度     1
        ///     3.TVOC浓度    2
        ///     4.温度         3
        ///     5.湿度         4
        /// 2   通道号 预留，这里只有一个通道
        /// 3   目标级别    Level: 0 ~ 7 每一级别对不同的组范围
        /// 注：0级为差
        ///     1.级为良
        ///     2 级为优
        /// 4   重复周期类型  0：系统     
        /// 1：自定义
        /// 5   重复周期设置  系统：
        ///     0：只执行一次
        ///     1：每天一次
        ///     2：工作日
        ///     3：周末, 非工作日 
        ///     0xff ： 重复无效
        /// 自定义：
        ///     启用第 6 个byte 来自定义一周里面的重复时间
        /// 6   自定义重复周期 Bit0 - bit6 代表周日到周六( 1:为选定  0：为取消) 第 4 byte 为 1 时有效
        /// 7   年   范围：公元年与2000的差
        /// 8   月   0 - 11
        /// 9   日   0 - 30
        /// 10  时   0 - 23
        /// 11  分   0 - 59 
        /// 12  年   范围：公元年与2000的差
        /// 13  月   0 - 11
        /// 14  日   0 - 30
        /// 15  时   0 - 23
        /// 16  分   0 - 59 
        /// </summary>
        SetSensorAutomationDateTimeCycle = 0x3561,
        /// <summary>
        /// 7.2日历逻辑设置返回
        /// 操作码: 0x3562
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:4
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5        0
        ///     2.CO2浓度     1
        ///     3.TVOC浓度    2
        ///     4.温度         3
        ///     5.湿度         4
        /// 2   通道号 预留，这里只有一个通道
        /// 3   目标级别    Level: 0 ~ 7 每一级别对不同的组范围
        /// 注：0级为差
        ///     1.级为良
        ///     2 级为优
        /// 4   Status  F8 / F5
        /// </summary>
        SetSensorAutomationDateTimeCycleACK = 0x3562,

        /// <summary>
        /// 7.3读日历逻辑
        /// 操作码: 0x3563
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:3
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5        0
        ///     2.CO2浓度     1
        ///     3.TVOC浓度    2
        ///     4.温度         3
        ///     5.湿度         4
        /// 2   通道号 预留，这里只有一个通道
        /// 3   目标级别    Level: 0 ~ 7 每一级别对不同的组范围
        ///     注：0级为差
        ///     1.级为良
        ///     2 级为优
        /// </summary>
        ReadSensorAutomationDateTimeCycle = 0x3563,
        /// <summary>
        /// 7.4读日历逻辑返回
        /// 操作码: 0x3564
        /// 通讯方式: 点对点
        /// 子网ID范围: 0-254   设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度:16
        /// 编号  备注  值域
        /// 1   类型  
        ///     1.PM2.5        0
        ///     2.CO2浓度     1
        ///     3.TVOC浓度    2
        ///     4.温度         3
        ///     5.湿度         4
        /// 2   通道号 预留，这里只有一个通道
        /// 3   目标级别    Level: 0 ~ 7 每一级别对不同的组范围
        /// 注：0级为差
        ///     1.级为良
        ///     2 级为优
        /// 4   重复周期类型  0：系统     
        /// 1：自定义
        /// 5   重复周期设置  系统：
        ///     0：只执行一次
        ///     1：每天一次
        ///     2：工作日
        ///     3：周末, 非工作日
        /// 自定义：
        ///     启用第 6 个byte 来自定义一周里面的重复时间
        /// 6   自定义重复周期 Bit0 - bit6 代表周日到周六( 1:为选定  0：为取消) 第 4 byte 为 1 时有效
        /// 7   年   范围：公元年与2000的差
        /// 8   月   0 - 11
        /// 9   日   0 - 30
        /// 10  时   0 - 23
        /// 11  分   0 - 59 
        /// 12  年   范围：公元年与2000的差
        /// 13  月   0 - 11
        /// 14  日   0 - 30
        /// 15  时   0 - 23
        /// 16  分   0 - 59 
        /// </summary>
        ReadSensorAutomationDateTimeCycleACK = 0x3564,



        #endregion

        /// <summary>
        /// 高级网关交换数据使用
        /// </summary>
        SuperGatewayAgent = 0xAEAE,
        SuperGatewayAgentACK = 0xAEAF,


        SonosControl = 0xAEB0,
        SonosControlACK = 0xAEB1,

        LogicstateControl = 0xE014,
        LogicstateControlACK = 0xE015,

        #region 新风协议
        //新风协议控制
        //附加数据：  新风通道号（1 - 200） + 开关（0，1） + 风速（0 关，1低，2中，3高） + 模式（0手动，1 自动,2 智能，3 定时）
        FreshAirControl = 0x144A,
        //返回：新风通道号（1 - 200） + 开关（0，1） + 风速（0 关，1低，2中，3高） + 模式（0手动，1 自动,2 智能，3 定时）+模拟量（2byte==16bit）+ 
        //室内温度(4byte) + 室外温度(4byte) + 室内湿度(4byte)+ PM2.5(4byte) + TVOC(4byte) + CO2(4byte)
        FreshAirControlACK = 0x144B,


        //2.新风协议读状态
        //附加数据：  新风通道号（1 - 200） 
        FreshAirRead = 0x144C,
        //返回：新风通道号（1 - 200） + 开关（0，1） + 风速（0 关，1低，2中，3高） + 模式（0手动，1 自动,2 智能，3 定时） +模拟量（2byte==16bit）+
        //室内温度(4byte) + 室外温度(4byte) + 室内湿度(4byte)+ PM2.5(4byte) + TVOC(4byte) + CO2(4byte)
        FreshAirReadACK = 0x144D,


        #endregion

        /// <summary>
        /// 布防设置       
        /// 附加数据
        /// area 区域号
        /// Armtype 布防类型   
        /// </summary>
        SetArm = 0x0104,
        /// <summary>
        /// 布防设置ACK     
        /// 附加数据
        /// area 区域号
        /// Armtype 布防类型   
        /// </summary>
        SetArmACK = 0x0105,

        /// <summary>
        /// 读取布防状态
        /// 附加数据
        /// area 区域号
        /// </summary>
        ReadArm = 0x011E,
        /// <summary>
        /// 布防设置ACK     
        /// 附加数据
        /// area 区域号
        /// Armtype 布防类型   
        /// </summary>
        ReadArmACK = 0x011F,


        /// <summary>
        /// 0x0000
        /// 无效指令
        /// </summary>
        Invoid = 0x0000,
        /// <summary>
        /// 0x000E
        /// 读取备注信息
        /// </summary>
        ReadRemark = 0x000E,
        /// <summary>
        /// 0x000F
        /// 读取备注信息反馈
        /// </summary>
        ReadRemarkACK = 0x000F,
        /// <summary>
        /// 0x0002
        /// 场景控派        /// 区域号（1B），【昂牛?）
        /// </summary>
        SetScene = 0x0002,
        /// <summary>
        /// 0x0003
        /// 场景控制回复
        /// 区域号（1B），场景号（1B），回路数（1B）?芈房?刈刺?н用 n bit 位表示）n: 回路个数 ；
        /// </summary>
        SetSceneACK = 0x0003,
        /// <summary>
        /// 0x001A
        /// 序列控制
        /// 区域号（1B），序列号（1B）
        /// </summary>
        SetSeries = 0x001A,
        /// <summary>
        /// 0x001B
        /// 序列控制回复
        /// 区域号（1B），序列号（1B）
        /// </summary>
        SetSeriesACK = 0x001B,
        /// <summary>
        /// 0xE01C
        /// 通用开关控制
        /// 开关号（1B），开关状态（1B）（0XFF：开；0：关）
        /// </summary>
        SetCommonSwitch = 0xE01C,
        /// <summary>
        /// 0xE01D
        /// 通用开关控制回复
        /// 开关号（1B??状塔?）（1：开；0：关）
        /// </summary>
        SetCommonACK = 0xE01D,

        /// <summary>
        /// 0xE3E4
        /// 广?    /// 各窗帘刺?нn B）（0:停止；1：开；2：闭n：为窗帘个数
        /// </summary>
        BroadcastCurtainStatus = 0xE3E4,
        /// <summary>
        /// 0x0031
        /// 调节控制
        /// 回路号（1B），开关量（1B）,0(时间1),0(奔?
        /// </summary>
        SetSingleLight = 0x0031,
        /// <summary>
        /// 0x0032
        /// 调节控制回成        
        /// 回路号（1B），0XF8/0XF5(1B) 开关量（1B）,
        /// 回路数（1B），回路开关状态（ 用 n bit 位表示）
        /// n: 回路个数 ；0XF8:成功；0XF5：失败
        /// </summary>
        SetSingleLightACK = 0x0032,
        /// <summary>
        /// 0x0033
        /// 单路调节读取状态
        /// 回路数（1B），各回路开关量（ n B）
        /// </summary>
        ReadLightEquipmentAllLoopBrightness = 0x0033,
        /// <summary>
        /// 0x0034
        /// 单路调节读取状态回复
        /// 1byte（回路总数）nbyte(每个字节表示对应回路的亮度0-100)
        /// </summary>
        ReadLightEquipmentAllLoopBrightnessACK = 0x0034,
        /// <summary>
        /// 0xE4F4
        /// 增加单个回路亮度值的读取
        /// 回路号
        /// </summary>
        ReadLightSingleLoopBrightness = 0xE4F4,
        /// <summary>
        /// 0xE4F5
        /// 增加单个回路亮度值的读取返回 
        /// 1byte（回路号）2byte（成功或者失败）3byte(回路的亮度0-100)
        /// </summary>
        ReadLightSingleLoopBrightnessACK = 0xE4F5,

        /// <summary>
        /// 读取能源开关功率
        /// [0](bit0-bit5) 2: 电压  3: 电流   10：功率   11：电能       (BIT 6-7    0:2bytes  1:1bytes 2:4bytes)
        /// [1] 通道   
        /// </summary>
        ReadAnalogValue = 0xE440,
        /// <summary>
        /// [0](bit0-bit5) 2: 电压  3: 电流   10：功率 (2byte) === 11：电能  (4byte)
        /// [1] 通道
        /// [2] 模拟量H1       电压值 0.1V,电流0.001,功率1W 
        /// [3] 模拟量H2                                                                                                                  
        /// [4] 模拟量H3                                                                                                                        
        /// [5] 模拟量H4       电量0.1度电
        /// </summary>
        ReadAnalogValueACK = 0xE441,


        /// <summary>
        /// 0x2142
        /// 密码认证
        /// </summary>
        SetHotelPassword = 0x2142,
        /// <summary>
        /// 0x2143
        /// 密码认证返回
        /// </summary>
        SetHotelPasswordACK = 0x2143,
        /// <summary>
        /// 0x2077
        /// 读取酒店门铃状态
        /// 无附加数据
        /// </summary>
        ReadHotelDoorState = 0x2077,
        /// <summary>
        /// 0x2078
        /// 取酒店门铃状塔馗成        
        ///  _ROOM_DOORBELL_STATUS_READ_ACK  0x2078  //ACK Read doorbell status
        /// doorbell status(1byte)--1/0(on/off)--bit0(wait)-bit1(disturb)-bit2(clean)-bit3(number)-bit4(bell),bit5(RF)
        /// Total: 1byte
        /// </summary>
        ReadHotelDoorStateACK = 0x2078,
        /// <summary>
        /// 0x209B
        /// 门铃状态广播
        ///  _ROOM_TOUCH_CONTROL_DATA_CMD  0x2142 //CMD Touch Control
        /// hdlmac(8bytes)
        /// Control_flag(1byte)---1(Enable)-2(Disable)
        /// Password(2byte)---(Disable no need these bytes)
        /// Total: 11bytes
        /// </summary>
        BroadcastHotelDoorState = 0x209B,
        /// <summary>
        /// 0x2079
        /// 门铃状态控制
        /// _ROOM_DOORBELL_STATUS_SET_CMD  0x2079 //Set doorbell status
        /// doorbell status(1byte)
        /// Total: 1byte
        /// </summary>
        SetHotelDoorState = 0x2079,
        /// <summary>
        /// 0x207A
        /// 门遄刺?刂品蠢犔
        /// _ROOM_DOORBELL_STATUS_SET_ACK  0x207A  //ACK Set doorbell status
        /// 0xf8/0xf5(1byte)
        /// same_send_data(1byte)
        /// Total: 2bytes
        /// </summary>
        SetHotelDoorStateACK = 0x207A,
        /// <summary>
        /// 0x2057
        /// 读取酒店所有状态
        /// hdlma(8bytes)
        /// </summary>
        ReadHotelAllState = 0x2057,
        /// <summary>
        /// 0x2058
        /// 读取酒店所有状态回复
        /// 
        /// _ROOM_STATUS_READ_ACK  0x2058 //ACK Read room_states
        /// hdlmac(8bytes)
        ///***Cancel***// Room_states(1byte)--bit0(check)-bit1(reserved),bit2-5(card type),bit6(stolen alarm)-bit7(help alarm)
        /// Room_states(1byte)----0(empty),1(On Service),2(reserve),3(chickin),4(Out of Service)---(*new add 2012-10-15*)
        /// Card_Type(1byte)---6 card type---(*new add 2012-10-15*)
        /// Current_que_no(1byte)--0-34(set_que)-0xFF(user custom)
        /// Doorbell_status(1byte)--bit0(wait)-bit1(disturb)-bit2(clean)-bit3(number)-bit4(bell),bit5(RF)
        /// Alarm_flag(1byte)--bit0(checkout)-bit1(stolen)-bit2(sos)-bit3(door)-bit4(server01)-bit5(server02)-bit6(server03)
        /// 48loop_level(48bytes)--(0-100)
        /// Total: 61bytes
        /// </summary>
        ReadHotelAllStateACK = 0x2058,
        /// <summary>
        /// 0x20D2
        /// 酒店主机所有状态广播
        /// </summary>
        BroadcaseHotelAllState = 0x20D2,
        /// <summary>
        /// 0x2069
        /// 窗帘控制
        ///  _ROOM_CURTAIN_STATUS_SET_ACK  0x206A  //ACK Set curtain status
        /// 0xf8/0xf5(1byte)
        /// curtain_num(1byte)
        /// curtain_staus(1byte)
        /// curtain_Now_staus(1byte)
        /// Total: 4bytes
        /// </summary>
        SetHotelCurtain = 0x2069,
        /// <summary>
        /// 0x206A
        /// 傲控制回赋冗       /// _ROOM_CURTAIN_STATUS_SET_ACK  0x206A  //ACK Set curtain status
        /// 0xf8/0xf5(1byte)
        /// curtain_num(1byte)
        /// curtain_staus(1byte)
        /// curtain_Now_staus(1byte)
        /// Total: 4bytes
        /// </summary>
        SetHotelCurtainACK = 0x206A,
        /// <summary>
        /// 0x2063
        /// 读取空调状态
        ///  _ROOM_AIR_STATUS_READ_CMD  0x2063 //Read air staus
        /// air No(1byte)--(1-4)
        /// total: 1byte
        /// </summary>
        ReadHotelAC = 0x2063,
        /// <summary>
        /// 0x2064
        /// 读取酒店主机空调状态回复
        ///  HOTEL_ROOM_AIR_STATUS_READ_ACK  0x2064 //ACK Read air staus
        ///*air No(1byte)--(1-4)
        /// air on/off(1byte)--0(off)-1(on)
        /// air cold temp(1byte)--(0~30"C)/(32~86"H)
        /// air_control_mode(1byte)--(high 4bit)0(cold)-1(hot)-2(close)-3(auto)---(low 4bit)0(auto)-1(high)-2(middle)-3(low)
        /// air panel lock flag(1byte)--0(unlock)-1(lock)---##
        /// air temp(1byte)--(0~40"C)/(32~104"H)
        /// air hot temp(1byte)--(0~30"C)/(32~86"H)
        /// air_run_mode(1byte)--same_air_control_mode
        /// air auto temp(1byte)--(0~30"C)/(32~86"H)     
        /// air_dry_temp(1byte)--(0~30"C)/(32~86"H)
        /// air_wind_sweep(1byte)--(0~close)/(1~open)
        /// Total: 11bytes
        /// </summary>
        ReadHotelACACK = 0x2064,
        /// <summary>
        /// 0x2065
        /// 控制酒店主机空调
        /// *  HOTEL_ROOM_AIR_STATUS_SET_CMD  0x2065 //Set air staus
        /// air No(1byte)--(1-4)
        /// air on/off(1byte)--0(off)-1(on)
        /// air cold temp(1byte)--(0~30"C)/(32~86"H)
        /// air_control_mode(1byte)--(high 4bit)-0(cold)-1(hot)-2(close)-3(auto)---(low 4bit)-0(auto)-1(high)-2(middle)-3(low)
        /// air panel lock flag(1byte)--0(unlock)-1(lock)---##
        /// air hot temp(1byte)--(0~30"C)/(32~86"H)
        /// air auto temp(1byte)--(0~30"C)/(32~86"H) 
        /// air_dry_temp(1byte)--(0~30"C)/(32~86"H)
        /// air_wind_sweep(1byte)--(0~close)/(1~open)
        /// Total: 9bytes
        /// </summary>
        SetHotelAC = 0x2065,
        /// <summary>
        /// 0x2066
        /// 控制酒店主机空调回复
        ///  HOTEL_ROOM_AIR_STATUS_SET_ACK  0x2066 //ACK Set air staus
        /// 0xf8/0xf5(1byte)
        /// same_send_data(9bytes)
        /// Total: 10bytes
        /// </summary>
        SetHotelACACK = 0x2066,
        /// <summary>
        /// 读取空调模块命令
        /// 1空调号(1-128) 
        /// 0x1938
        /// </summary>
        ReadACMode = 0x1938,
        /// <summary>
        /// 读取空调模块回复
        /// 1空调号(1-128) 
        ///2温度模式(摄氏Celsius:0，华氏Fahrenheit:1)                                     
        ///3环境温度 (摄氏0-40，华氏32-99)    
        ///4制冷控制温度(摄氏0-30，华氏32-86)    
        ///5制热控制温度(摄氏0-30，华氏32-86)
        ///6远?制虑缟闵?，华氏32-86)                                                                                           
        ///7除湿控制温度(摄氏0-30，华氏32-86)
        ///8模式风速实际工作状态, 高4bit模式(0 制冷，1制热，2通风，3自动，4除湿) 0xF1>>4 低4bit风速(0 自动，1高?风，3低风)0xF1&0x0F
        ///9空调开关                 (1开0关)           
        ///10设置模式                0 评?热，2通风，3自动，4除湿
        ///11设置风速                0 自动，1高风，2中风?风          
        ///12工作模式控制温度 (摄氏0-30，华氏32-86)         
        ///13扫风模式：高4bit(实际扫风状态：0不扫风，1扫风)，低4bit(设置扫风模剑?扫风，1扫风)
        /// 0x1939
        /// </summary>
        ReadACModeACK = 0x1939,
        /// <summary>
        /// 设置空调模块命令
        /// 1空调号(1-128) 
        ///2温度模式(摄氏Celsius:0，华氏Fahrenheit:1)                                     
        ///3环境温度 (摄氏0-40，华氏32-99)    
        ///4制冷控制温度(摄氏0-30，华氏32-86)    
        ///5制热控制温度(摄氏0-30，华氏32-86)
        ///6自动控制温度(摄氏0-30，华氏32-86)                                                                                           
        ///7除湿控制温度(摄氏0-30，华氏32-86)
        ///8椒缢偈导使ぷ髯此?  高4bit模式(0 制冷，1制热，2通风)  低4bit风速(0 自动，1高风?风，3低风)
        ///9空调开关                 (1开0关)           
        ///10设置模式               0 制冷1制热，2通风，3自动，4除湿
        ///11设置风速                0 自动，1高风2中风，3低风          
        ///12工作模控制温肚掮摄氏0-30，华氏32-86)         
        ///13扫风模式：高4bit(实际扫风状态：0不扫风，1扫风)，低4bit(设置扫风模式：0不扫风，1扫风)
        /// 0x193A
        /// </summary>
        SetACMode = 0x193A,
        /// <summary>
        /// 设置空调模块命令回复
        /// 1空调号(1-128) 
        ///2温度模式(摄氏Celsius:0，华氏Fahrenheit:1)                                     
        ///3环境温度 (摄氏0-40，华氏32-99)    
        ///4制冷控制温度(摄氏0-30，华氏32-86)    
        ///5制热控制温度(摄氏0-30，华氏32-86)
        ///6自动控制温度(摄氏0-30，华氏32-86)                                                                                           
        ///7除湿控制露晴摄氏0-30，华氏32-86)
        ///8模式风速实使作壮?  高4bit模式(0 ?龋?风，3自动，4除湿)  低4bit风速(0 自动，1高风，2蟹?风)
        ///9空调开关                 (1开0关)           
        ///10设置模式                0 制冷，1迫龋?风，3自动，4除湿
        ///11设置风速                0 自动，1高风，2中纾?风          
        ///12工作模式控制温度 (摄氏0-30，华氏32-86)         
        ///13扫风模式：?it(实噬ǚ缱刺?扫风，1扫风)，低4bit(设置扫风模式：0簧ǚ纾?风)
        /// 0x193B
        /// </summary>
        SetACModeACK = 0x193B,

        /// <summary>
        /// 分配地址，不清空之前列表
        /// 操作码: 0x13F4
        /// 通讯方式: 广播
        /// 子网ID范围: 0-254     设备ID范围: 0-254
        /// 附加数据内容
        /// 附加数据长度: 7
        /// 编号    备注    值域
        /// 1    发送数据标识    1=第一次请求分配地址；2 = 第二次请求 || 0x11 刷新地址列表 || 0x81 删除地址列表 || 0xA1 读取地址列表 
        ///    2    随机数（预留）    0 - 255
        ///    3    随机数（预留）    0 – 255 
        ///    4    随机数（预留）    0 – 255 
        ///    5    随机数（预留）    0- 255
        ///    6    随机数（预留）    0- 255
        ///    7    随机数（预留）    0- 255
        /// 注意：上位机需在10s内发送两次请求命令，第一次和第二次标识分清，交换机才会执行
        /// </summary>
        AssignedAddress = 0x13F4,
        AssignedAddressACK = 0x13F5,

        /// <summary>
        /// 定位设备
        /// E442,1D40定位面板
        /// </summary>
        PositioningEquipment = 0xE442,
        PositioningEquipmentACK = 0xE443,
        PositioningPanel = 0x1D40,
        PositioningPanelACK = 0X1D41,


        /// <summary>
        /// 搜索无线网关和一端口交换机
        /// </summary>
        ReadGateway = 0xE54A,
        ReadGatewayACK = 0xE54B,

        ReadGatewayProgrammingMode = 0x1400,
        ReadGatewayProgrammingModeACK = 0x1401,


        SetGateway = 0xE54C,
        SetGatewayACK = 0xE54C,
        /// <summary>
        /// 第一次搜索指令
        /// 操作码: 0xE548
        /// </summary>
        ReadDeviceModul = 0xE548,
        /// <summary>
        /// 第一次搜指令回复
        /// 操作码: 0xE549
        ///通讯方式: 点对点
        /// </summary>
        ReadDeviceModulACK = 0xE549,
        /// <summary>
        /// 搜索之后直接读取设备
        /// 操作码: 0xE44A
        ///通讯方式: 点对点
        ///子网ID范围: 0-254     设备ID范围: 0-254
        ///附加数据内容
        ///附加数据长度: 3
        ///编号    备注    涤裆        
        ///1    大类别   0 – 255 
        ///2    小类别    0 - 255
        ///3    回路号或者通道号    0- 255
        /// </summary>
        ReadDeviceLoopInfo = 0xE44A,
        /// <summary>
        /// 搜索之后直接读取设备反馈
        /// 操作码: 0xE44B
        ///ㄑ斗绞践 点缘馍        ///子网ID范围: 0-254     设备ID范围: 0-254
        ///附加数据内容
        ///附加数据长度: N
        ///编号    备注    值域
        ///1    大类别    0 – 255 
        ///2    小类锶0 - 255
        ///3    回路或咄ǖ朗?0- 255
        ///4    备注第1个byte    0 - 255
        ///5    备注第2个byte    0- 255
        ///…
        ///23    备注第20鯾yte    0- 255
        /// 具体参数见下表(其中回路或者通道数，备注为重复部分，无需重复返回，当前状态不用修改)
        /// </summary>
        ReadDeviceLoopInfoACK = 0xE44B,
        /// <summary>
        /// 设置简易编程设备基本信息
        /// 操作码: 0xE44C
        ///通讯方式: 点对点
        ///子网ID范围: 0-254     设备ID范围: 0-254
        ///附加数据内容
        ///附加数据长度: 4 + 2 N
        ///编号    备注    值域
        ///1    大类别    0 – 255 
        ///2    小类别    0 - 255
        ///3    回路或者通道数    1- 255
        ///4    备注第1个byte    0 - 255
        ///5    备注第2个byte    0- 255
        ///…
        ///23    备注第20个byte    0- 255
        ///具体参数见下表(其中回路或咄ǖ朗??缸⑽?馗床糠?扌柚馗捶祷兀?鼻按塔挥眯薷描
        /// </summary>
        SetDeviceLoopInfo = 0xE44C,
        /// <summary>
        /// 操作码: 0xE44D
        ///通讯方式: 点对点
        ///子鳬D范围: 0-254     设ID范围: 0-254
        ///附加数据内容
        ///附加数据长度: 3
        ///编号    备注    值域
        ///1    大类别    0 – 255 
        ///2    小类别    0 - 255
        ///3    回路或者通道数    0 - 255
        /// </summary>
        SetDeviceLoopInfoACK = 0xE44D,
        ///// <summary>
        ///// 简易编程读取第一次读〔煌甑奈尴呱璞感畔∩        /// //[0]gateway netID 0~254    255是广播搜索      新版本上加，
        ///// </summary>
        //ReadOnePortWirelessFROtherInfo = 0x1D34,
        ///// <summary>
        ///// 简易编程读取第一次读取不完的无线设备信息反馈,从第五个字节索引开始
        ///// //[0]mode :  0:normal   1:config_mode                                                                                                              
        /////[1]control byte    bit0 1:GateNet   0:general note                                              
        /////[2] 
        /////[3] 
        /////[4] 
        /////[5] RSSI(-dbm)
        /////[5]对应频段 
        /////0((Chinese WPAN Band))  1(-European SRD Band)  2-(North_American ISM Band)
        /////[6]channel(Center Frequency)
        /////((Chinese WPAN Band)): 0~12
        /////标准0-780MHz,782,784,3-786MHz,
        /////（nonstandard）,用非标准请慎重4-770MHz 5-772MHz,6-774MHz,7-776MHz,8-778Mz,9-788MHz,10-790MHz,11-792MHz,12-794MHz    
        /////(European SRD Band)(0~12)
        /////标准0-864MHz,1-866MHz,2-868MHz.3-870MHz
        /////（nonstandard）4-858MHz,5-860MHz,6-862MHz，7-872MHz,8-874MHz,9-876MHz,10-878MHz,11-880MHz,12-882MHz,
        /////(North_American ISM Band):（0~12）
        /////标准北美频段， 0-904MHz,906,908,910,912,914,916,918,920,922,924,926,12-928MHz
        /////[8]~[23] SECURITY_KEY
        /////[24]~[43] Device_Remark_Buf
        ///// </summary>
        //ReadOnePortWirelessFROtherInfoACK = 0x1D35,


        ///修改设备模块Remake通用指令
        UpdataRemake = 0x0010,
        UpdataRemakeACK = 0x0011,

        /// <summary>
        /// F010
        /// The update loop remake.
        /// </summary>
        UpdateEquipmentLoopRemake = 0xF010,
        UpdateLightDimmingLoopRemakeACK = 0xF011,

        /// <summary>
        /// The update wireless panel button key remark.
        /// </summary>
        UpdateWirelessPanelButtonKeyRemark = 0xE006,
        UpdateWirelessPanelButtonKeyRemarkACK = 0xE007,

        /// <summary>
        /// 读取按键信息
        /// E000
        /// </summary>
        ReadWirelessPanelButtonKey = 0xE000,
        ReadWirelessPanelButtonKeyACK = 0xE001,

        /// <summary>
        /// e002
        /// </summary>
        WriteWirelessPanelButtonKey = 0xE002,
        WriteWirelessPanelButtonKeyACK = 0xE003,

        ReadWirelessPanelButtonKeyRemark = 0xE004,
        ReadWirelessPanelButtonKeyRemarkACK = 0xE005,

        /// <summary>
        /// 读取按键目标使能/
        /// 按键配置了多少控制目标，在哪个序列上，
        /// send ：1 byte （回路号）
        /// Receive ： 1（回路号）2（目标总数）+ 使能（byte总数不确定，转化成二进制，1代表有效，0代表无效）
        /// </summary>
        ReadButtonKeyEnable = 0xE474,
        ReadButtonKeyEnableACK = 0xE475,

        ReadDrycontactMode = 0xD205,
        ReadDrycontactModeACK = 0xD206,
        ReadWirelessPanelMode = 0xE008,
        ReadWirelessPanelModeACK = 0xE009,
        /// <summary>
        /// 修改按键模式
        /// </summary>
        UpdataDrycontactMode = 0xD207,
        UpdataDrycontactModeACK = 0xD208,
        UpdataWirelessPanelModel = 0xE00A,
        UpdataWirelessPanelModelACK = 0xE00B,
        /// <summary>
        /// 控制面板
        /// 3byte 
        /// 固定  17
        /// 状态 0关 1开
        /// 回路号
        /// </summary>
        InstructionPanelKey = 0xE3D8,
        InstructionPanelKeyACK = 0xE3D9,
        //============================温度========================================//
        //面板 广播温度
        //通道号,   0-255       1btye//面板默认为1                                     
        //摄氏温度值，         1btye    //注意：temperature为负数的时候，最高位置1
        //摄氏温度浮点值1      1byte    //20110328加//把浮点值按存储的4个byte发送
        //摄氏温度浮点值2      1byte    //20110328加//把浮点值按存储的4个byte发送    
        //摄氏温度浮点值3      1byte    //20110328加//把浮点值按存储的4个byte发送   
        //摄氏温度浮点值4      1byte    //20110328加//把浮点值按存储的4个byte发送  
        PanleBroadcastTemp = 0xE3E5,
        ////未用
        //PanleBroadcastTempACK = 0xE3E6,
        //读温度
        //通道号,   0-255       1btye//面板默认为1                                   
        //读温度返回
        ReadPanleTemp = 0xE3E7,
        //通道号,   0-255       1btye//面板默认为1                                  
        //摄氏温度值，         1btye      //注意：temperature为负数的时候，最高位置1
        //20151013
        //摄氏温度浮点值1      1byte    //20110328加//把浮点值按存储的4个byte发送
        //摄氏温度浮点值2      1byte    //20110328加//把浮点值按存储的4个byte发送    
        //摄氏温度浮点值3      1byte    //20110328加//把浮点值按存储的4个byte发送   
        //摄氏温度浮点值4      1byte    //20110328加//把浮点值按存储的4个byte发送  
        ReadPanleTempACK = 0xE3E8,
        /// <summary>
        /// 读取面板状态
        /// </summary>
        ReadInstructionPanelKey = 0xE3DA,
        ReadInstructionPanelKeyACK = 0xE3DB,


        /// <summary>
        /// The updata light dimming maximum.
        /// </summary>
        UpdataLightDimmingMaximumOrMinimum = 0xF018,
        UpdataLightDimmingMaximumOrMinimumACK = 0xF019,

        /// <summary>
        /// The updata light dimming the largest level.
        /// </summary>
        UpdataLightDimmingTheLargestLevel = 0xF022,
        UpdataLightDimmingTheLargestLevelACK = 0xF023,

        /// <summary>
        /// 进入无线配置模式.
        /// </summary>
        GotoConfigMode = 0X1D38,
        GotoConfigModeACK = 0X1D39,//20170524更换操作码 : 20171215g改回
        //GotoConfigMode = 0X1D52,
        //GotoConfigModeACK = 0X1D53,
        /// <summary>
        /// 退出无线配置模式
        /// </summary>
        CheckConfigSuccess = 0x1D3A,
        CheckConfigSuccessACK = 0x1D3B,

        /// <summary>
        /// 修改窗帘模块运行时间
        /// </summary>
        UpdataCurtainModelRunTime = 0xE802,
        UpdataCurtainModelRunTimeACK = 0xE803,

        /// <summary>
        /// 修改窗帘模块状态//安装调试
        /// 测试窗帘
        /// E3E0 附加数据2个byte
        /// 继电器窗帘的话第一个byte的就代表回路号 第二个代表0/1/2代表停止/开/关
        /// 电机窗帘的话第一个byte固定17, 第二个byte代表百分比（0-100）
        /// 开合帘测距时附加数据为17，238
        /// 
        /// 
        /// 
        /// 
        /// 进入安装调试:命令E3E0 附加数据3个byte 第一个17 第二个 238 第三个1 反馈E3E1 反馈的附加数据第一个byte为17 第二个byte为238 第三个byte为1时表示进入安装调试成功
        /// 确定起始位置 命令E3E0附加数据2个byte, 第一个byte1，第二个byte1 反馈命令E3E1 反馈的附加数据第一个byte为1 第二个byte为1表示开始确实确定起始位置 电机转动
        /// 起始位置确定完成 命令 1F0C 附加数据1个byte 第一个byte为3 反馈命令1F0D 反馈的附加数据第一个byte为3时表示确定起始位置完成
        /// 确定结束位置 命令E3E0附加数据2个byte, 第一个byte1，第二个byte2 反馈命令E3E1 反馈的附加数据第一个byte为1 第二个byte为2表示开始确定结束位置 电机转动
        /// 结束位置确定完成 命令 1F0C 附加数据1个byte 第一个byte为2 反馈命令1F0D 反馈的附加数据第一个byte为2时表示确定结束位置完成
        /// 退出安装调试 命令E3E0 附加数据3个byte 第一个17 第二个 238 第三个2 反馈E3E1 反馈的附加数据第一个byte为17 第二个byte为238 第三个byte为2时表示退出安装调试成功
        /// 点动 命令E3E0 附加数据2个byte  第一个33 第二个：点动开为1，点动关2
        /// </summary>
        SetCurtainModelStutas = 0xE3E0,
        SetCurtainModelStutasACK = 0xE3E1,

        /// <summary>
        /// 窗帘模块状态广播回复
        /// </summary>
        CurtainModelStutasACK = 0xE3E4,

        /// <summary>
        /// 确定窗帘位置完成
        /// 测试窗帘
        /// </summary>
        UpdataCurtainLocalFinish = 0x1F0C,
        UpdataCurtainLocalFinishAck = 0x1F0D,

        /// <summary>
        /// 读取窗帘电机方向
        /// </summary>
        ReadCommandCurtainUserseting = 0x1F02,
        ReadCommandCurtainUsersetingAck = 0x1F03,

        /// <summary>
        /// 开关状态选择标记
        /// 1表示向前，0表示向后
        /// </summary>
        CommandCurtainUserseting = 0x1F00,
        CommandCurtainUsersetingAck = 0x1F01,

        /// <summary>
        /// E3E2是读取窗帘状态的
        /// 附加数据一个byte
        /// 继电器窗帘就是回路号
        /// 电机窗帘固定17
        /// 返回回路号+窗帘状态
        /// 电机窗帘0-100的话表示当前百分比，0XDD的话代表不能获取百分比需要复位  0XEE代表窗帘处于安装调试状态
        /// </summary>
        ReadCurtainStatus = 0xE3E2,
        ReadCurtainStutasACK = 0xE3E3,

        /// <summary>
        /// 3007
        /// 读取一端口交换机、无线网关的配置信息
        /// </summary>
        ReadGateWayModelInfo = 0x3007,
        ReadGateWayModelInfoACK = 0x3008,

        /// <summary>
        /// 读取网关设备的服务器ip信息
        /// </summary>
        ReadGatewayServerIP = 0x3009,
        ReadGatewayServerIPACK = 0x300A,

        /// <summary>
        /// 测试发送远程数据到服务器是否存在相同的组名用户名
        /// 附加数据内容：   工程备注                   20 bytes
        /// 群组备注                         20 bytes
        /// 远程访问的用户名                  8 bytes
        /// 设备本身的MAC码(保证此数据唯一)  8 bytes
        /// ----
        /// 附加数据长度：9bytes
        /// 附加数据内容：1byte 0失败 1成功 2已经存在
        /// </summary>
        SendRemoteInfoToServer = 0x300B,
        SendRemoteInfoToServerACK = 0x300C,

        /// <summary>
        /// 设置交换机模块组名工程名
        /// </summary>
        SetGateWayModelInfo = 0x3003,
        SetGateWayModelInfoACK = 0x3004,

        /// <summary>
        /// 3005
        /// 设置交换机网络功能信息
        /// </summary>
        SetGateWayModelInternetInfo = 0x3005,
        SetGateWayModelInternetInfoACK = 0x3006,

        /// <summary>
        /// 0xF003
        /// 读取设备mac地址
        /// </summary>
        ReadDeviceMac = 0xF003,
        ReadDeviceMacACK = 0xF004,

        /// <summary>
        /// 0xF005
        /// 设置设备子网号、设备号
        /// </summary>
        SetDeviceSubnetID = 0xF005,
        SetDeviceSubnetIDACK = 0xF006,

        /// <summary>
        /// 读取地热信息
        /// [0]number(1-6)
        /// 回复
        /// [0]number(1-6) 地热号                                            (1byte)
        /// [1]模式&开关：高4bit(0地热模式、1地冷模式、2地热功率控制、3地冷功率控制)，低4bit(0关、1开，地热模块里面不支持，低4位扩展)       (1byte) 
        /// [2]温度单位(摄氏Celsius:0，华氏Fahrenheit:1)                       (1byte)
        /// [3]工作模式：1:普通,2:白天,3:夜晚,4:离开,5:时间     (1-5)          (1byte) 
        /// [4]普通：设置温度(摄氏0-100，华氏32-212)/功率值(0-10)               (1byte)  
        /// [5]白天：设置温度(摄氏0-100，华氏32-212)/功率值(0-10)               (1byte) 
        /// [6]夜晚：设置温度(摄氏0-100，华氏32-212)/功率值(0-10)               (1byte)
        /// [7]离开：设置温度(摄氏0-100，华氏32-212)/功率值(0-10)               (1byte)
        /// [8]时间模式的时间段标志           (0：白天，1：夜晚)               (1byte)     //20110112加时间段标志
        /// [9]温度源温度(最高位0:正,1:负.后7bit为值)                          (1byte) 
        /// [10]阀的开关状态(0--关   1--开)
        /// [11]阀的大小    (0~100)
        /// [12]冲洗标记                       高4位：1按键执行冲洗、0非按键执行(模块定时冲洗)冲洗，低4位： 0：不冲洗、1冲洗    (1byte)
        /// [13]冲洗时间              1~30(min)                        (1byte)
        /// </summary>
        ReadFloorHeat = 0x1C5E,
        ReadFloorHeatACK = 0x1C5F,
        /// <summary>
        /// 地热控制指令
        /// [0]number(1-6) (1byte)
        /// [1]模式&开关：高4bit(0地热模式、1地冷模式、2地热功率控制、3地冷功率控制)，低4bit(0关、1开，地热模块里面不支持，低4位扩展)       (1byte)    
        /// [2]温度单位(摄氏Celsius:0，华氏Fahrenheit:1) (1byte)
        /// [3]工作模式：1:普通,2:白天,3:夜晚,4:离开,5:时间 (1-5) (1byte) 
        /// [4]普通：设置温度(摄氏0-100，华氏32-212)/功率值(0-10) (1byte)  
        /// [5]白天：设置温度(摄氏0-100，华氏32-212)/功率值(0-10) (1byte) 
        /// [6]夜晚：设置温度(摄氏0-100，华氏32-212)/功率值(0-10) (1byte)
        /// [7]离开：设置温度(摄氏0-100，华氏32-212)/功率值(0-10) (1byte)
        /// [8](固定0)冲洗标记 高4位：1按键执行冲洗、0非按键执行(模块定时冲洗)冲洗，低4位： 0：不冲洗、1冲洗     (1byte)
        /// [9](固定0)冲洗时间 1~30(min)  
        /// 回复
        /// [0]number(1-6) 地热号 (1byte)
        /// [1]模式&开关：高4bit(0地热模式、1地冷模式、2地热功率控制、3地冷功率控制)，低4bit(0关、1开，地热模块里面不支持，低4位扩展)       (1byte) 
        /// [2]温度单位(摄氏Celsius:0，华氏Fahrenheit:1) (1byte)
        /// [3]工作模式：1:普通,2:白天,3:夜晚,4:离开,5:时间 (1-5) (1byte) 
        /// [4]普通：设置温度(摄氏0-100，华氏32-212)/功率值(0-10) (1byte)  
        /// [5]白天：设置温度(摄氏0-100，华氏32-212)/功率值(0-10) (1byte) 
        /// [6]夜晚：设置温度(摄氏0-100，华氏32-212)/功率值(0-10) (1byte)
        /// [7]离开：设置温度(摄氏0-100，华氏32-212)/功率值(0-10) (1byte)
        /// [8]时间模式的时间段标志 (0：白天，1：夜晚) (1byte) //20110112加时间段标志
        /// [9]温度源温度(最高位0:正,1:负.后7bit为值) (1byte) 
        /// [10]阀的开关状态(0--关 1--开)
        /// [11]阀的大小 (0~100)
        /// [12]冲洗标记 高4位：1按键执行冲洗、0定时冲洗)冲洗，低4位： 0：不冲洗、1冲洗    (1byte)
        /// [13]冲洗时间 1~30(min) (1byte)
        /// </summary>
        SetFloorHeat = 0x1C5C,
        SetFloorHeatACK = 0x1C5D,
        ///Serverx_FH_CMD E45A
        ///0   地热号 1-N
        ///1   工作模式    0地热模式、1地冷模式、2地热功率控制、3地冷功率控制、4自动
        ///2   开关时      0=OFF，1=ON
        ///3   工作模式  1:普通,2:白天,3:夜晚,4:离开,5:时间
        ///4   温度点    5-35
        ///5   冲洗标志    编码            说明
        ///            4，5，6，7bit    Server暂时不用
        ///            0，1，2，3bit    0=不冲洗，1=冲洗
        ///6   冲洗时间    1-30Min
        ///7   功能号      0 = 无状态  (读)
        ///             1、2=开关
        ///             3=向下设定温度点
        ///             4=向上设定温度点
        ///             5=室内温度
        ///             6=室馕露巧        ///             7=向下工作温度模式
        ///             8=向上工作温度模模式
        Serverx_FH_CMD = 0xE45A,
        Serverx_FH_CMD_ACK = 0xE45B,
        /// <summary>
        /// The read terrestria heat remark.
        /// </summary>
        ReadTerrestriaHeatRemark = 0x1D02,
        ReadTerrestriaHeatRemarkACK = 0x1D03,

        SetTerrestriaHeatRemark = 0x1D00,
        SetTerrestriaHeatRemarkACK = 0x1D01,

        #region   面板地热状态 
        /// <summary>
        /// 地热页号0-8                                       (1byte)//彩屏加入20150714
        /// </summary>
        Read_Floor_Heat_State = 0x1944,
        /// <summary>
        /// 1温度模式(摄氏Celsius:0，华氏Fahrenheit:1)                         (1byte)
        /// 2温度源温度(最高位0:正,1:负.后7bit为值)                             (1byte)
        /// 3地热地冷开关：：0关、1开                                           (1byte)
        /// 4工作温度模式：1:普通,2:白天,3:夜晚,4:离开,5:时间     (1-5)             (1byte) 
        /// 5普通温度                       (摄氏0-99，华氏32-210)              (1byte)  
        /// 6白天温度                       (摄氏0-99，华氏32-210)              (1byte) 
        /// 7夜晚温度                       (摄氏0-99，华氏32-210)              (1byte)
        /// 8离开温度                       (摄氏0-99，华氏32-210)              (1byte)
        /// 9时间模式的时间段标志           (0：白天，1：夜晚)                      (1byte)  //20110112加时间段标志
        /// 10模式：0地热模式、1地冷模式、2自动                                 (1byte)    //20120802加//20140805加自动
        /// 11地热页号0-8                                       (1byte)//彩屏加入20150714
        /// </summary>
        Read_Floor_Heat_State_ack = 0x1945,

        /// <summary>
        /// 1温度模式(摄氏Celsius:0，华氏Fahrenheit:1)                         (1byte) 
        /// 2地热地冷开关：：0关、1开                                           (1byte)
        /// 3工作温度模式：1:普通,2:白天,3:夜晚,4:离开,5:时间     (1-5)            (1byte)
        /// 4普通温度                       (摄氏0-99，华氏32-210)             (1byte)  
        /// 5白天温度                       (摄氏0-99，华氏32-210)             (1byte) 
        /// 6夜晚温度                       (摄氏0-99，华氏32-210)             (1byte)
        /// 7离开温度                       (摄氏0-99，华氏32-210)             (1byte)
        /// 8地热页号0-8                                       (1byte)//彩屏加入20150714  
        /// </summary>
        Set_Floor_Heat_State = 0x1946,
        /// <summary>
        /// 1MODIFY_FAULT                              1 byte
        /// 2地热页号0-8                                       (1byte)//彩屏加入20150714    
        /// 或---------------------------------------------- 
        /// 1 MODIFY_SUCCESS                          1 byte
        /// 2温度模式(摄氏Celsius:0，华氏Fahrenheit:1)                         (1byte) 
        /// 3地热地冷开关：：0关、1开                                           (1byte)
        /// 4工作温度模式：1:普通,2:白天,3:夜晚,4:离开,5:时间     (1-5)            (1byte) 
        /// 5普通温度                       (摄氏0-99，华氏32-210)             (1byte)  
        /// 6白天温度                       (摄氏0-99，华氏32-210)             (1byte) 
        /// 7夜晚温度                       (摄氏0-99，华氏32-210)             (1byte)
        /// 8离开温度                       (摄氏0-99，华氏32-210)             (1byte)
        /// 9时间模式的时间段标志           (0：白天，1：夜晚)                     (1byte)  //20120802加
        /// 10工作模式：0地热、1地冷、2自动                                     (1byte)     //20120802加//20140805加自动   
        /// 11地热地冷同步标志：0不同步、1同步                                   (1byte)  //20121226加
        /// 12地热页号0-8                                       (1byte)//彩屏加入20150714  
        /// </summary>
        Set_Floor_Heat_State_ack = 0x1947,     //广播返回
        #endregion
        #region 4.3寸面板  空调状态 新协议
        /// <summary>
        /// [0]//空调页号(0-8)                                          1byte
        /// </summary>
        Read_Air_State_New = 0x19AE,
        /// <summary>
        /// [0]//空调页号(0-8)                                          1byte
        /// [1]//空调开关(1开0关)                                       1byte      
        /// [2]//制冷控制温度(摄氏0-30，华氏32-86)                       1byte   
        /// [3]//制热控制温度(摄氏0-30，华氏32-86)                       1byte
        /// [4]//自动控制温度(摄氏0-30，华氏32-86)                       1byte                                                                                           
        /// [5]//除湿控制温度(摄氏0-30，华氏32-86)                       1byte
        /// [6]//设置模式(0制冷，1制热，2通风，3自动，4除湿)              1byte
        /// [7]//设置风速(0自动，1高风，2中风，3低风)                     1byte //注意:当模式为除湿或模式为通风及风速为自动时，风速视为小风为准         
        /// [8]//设置扫风(0不扫风，1扫风)                                1byte
        /// [9]//温度模式(摄氏Celsius:0，华氏Fahrenheit:1)               1byte 
        /// [10]//模式实际工作状态(0制冷，1制热，2通风，3自动，4除湿)      1byte 
        /// [11]//风速实际工作状态(0关闭，1高风，2中风，3低风)             1byte         
        /// [12]//扫风实际工作状态(0不扫风，1扫风)                     1byte
        /// [13]//环境温度(摄氏0-40，华氏32-99)                          1byte  
        /// </summary>
        Read_Air_State_New_ack = 0x19AF,
        /// <summary>
        /// [0]//空调页号(0-8)                                          1byte
        /// [1]//空调开关(1开0关)                                       1byte      
        /// [2]//制冷控制温度(摄氏0-30，华氏32-86)                       1byte   
        /// [3]//制热控制温度(摄氏0-30，华氏32-86)                       1byte
        /// [4]//自动控制温度(摄氏0-30，华氏32-86)                       1byte                                                                                           
        /// [5]//除湿控制温度(摄氏0-30，华氏32-86)                       1byte
        /// [6]//设置模式(0制冷，1制热，2通风，3自动，4除湿)              1byte
        /// [7]//设置风速(0自动，1高风，2中风，3低风)                     1byte //注意:当模式为除湿或模式为通风及风速为自动时，风速视为小风为准         
        /// [8]//设置扫风(0不扫风，1扫风)                                1byte
        /// [9]//温度模式(摄氏Celsius:0，华氏Fahrenheit:1)               1byte 
        /// </summary>
        Set_Air_State_New = 0x19B0,  //pyx,6byte
        /// <summary>
        ///  MODIFY_FAULT                              1 byte
        /// 或---------------------------------------------- 
        /// [0]//MODIFY_SUCCESS                                          1byte
        /// [1]//空调页号(0-8)                                          1byte
        /// [2]//空调开关(1开0关)                                       1byte       
        /// [3]//制冷控制温度(摄氏0-30，华氏32-86)                       1byte   
        /// [4]//制热控制温度(摄氏0-30，华氏32-86)                       1byte
        /// [5]//自动控制温度(摄氏0-30，华氏32-86)                       1byte                                                                                           
        /// [6]//除湿控制温度(摄氏0-30，华氏32-86)                       1byte
        /// [7]//设置模式(0制冷，1制热，2通风，3自动，4除湿)              1byte
        /// [8]//设置风速(0自动，1高风，2中风，3低风)                     1byte //注意:当模式为除湿或模式为通风及风速为自动时，风速视为小风为准           
        /// [9]//设置扫风(0不扫风，1扫风)                                1byte
        /// [10]//温度模式(摄氏Celsius:0，华氏Fahrenheit:1)               1byte 
        /// [11]//模式实际工作状态(0制冷，1制热，2通风，3自动，4除湿)      1byte 
        /// [12]//风速实际工作状态(0关闭，1高风，2中风，3低风)             1byte      
        /// [13]//扫风实际工作状态(0不扫风，1扫风)                      1byte
        /// [14]//环境温度(摄氏0-40，华氏32-99)                          1byte  
        /// </summary>
        Set_Air_State_New_ack = 0x19B1,                             //是否广播待定！！！
        #endregion
        #region 面板空调状态 旧协议
        //------------------------------------------------------//设置空调工作状态
        /// <summary>
        /// nop
        /// </summary>
        Read_Air_Condition_Set = 0xE0EC,
        /// <summary>
        /// [0]//On_off(1byte)(FALSE,TRUE)
        /// [1]//Set_cooling_temperatrue （0-30）  
        /// [2]//Set_Mode (1byte)           //注意:当模式为除湿或模式为通风及风速为自动时，风速视为小风为准
        /// [3]//LOcal_Flag (1byte)
        /// [4]//Now_temprature(1byte) （0-40）
        /// [5]//set_heating temperature（0-30）
        /// [6]//Actual_Mode 
        /// [7]//set_Autoing temperature（0-30）
        /// [8]//set_DRYing temperature （0-30）
        /// [9]//set_WIND_MOVE_MODE       //高4bit(实际扫风状态：0不扫风，1扫风)，低4bit(设置扫风模式：0不扫风，1扫风)(20100505)
        /// </summary>
        Read_Air_Condition_Set_ack = 0xE0ED,

        ///// <summary>
        ///// 读取面板空调的状态
        ///// 开关号 
        ///// </summary>
        //ReadACPanelStatus = 0xE0EC,
        ///// <summary>
        ///// 开关状态 
        ///// 制冷温度 
        ///// 模式和风速  
        ///// 空调锁 
        ///// 当前温度 
        ///// 制热温度 
        ///// 空调实际运行模式和风速 
        ///// 自动温度 
        ///// 抽湿温度 
        ///// 空调是否扫风(低四位)  
        ///// 回路号（四点三寸面板才会有回复这个byte）
        ///// </summary>
        //ReadACPanelStatusACK = 0xE0ED,


        #endregion

        /// <summary>
        /// 远程访问的连续三个步骤
        /// 控制端连接服务器获取一端口的信息
        /// 远程访问的用户名             8 bytes
        /// 工程备注                   20 bytes
        /// 控制端连接服务器获取一端口的信息
        /// 0x300D
        /// </summary>
        RemoteFirst = 0x300D,
        RemoteFirstACK = 0x300E,
        /// <summary>
        /// 要求服务器是否要转发数据.
        /// 操作码：$301F
        ///附加数据长度：7byte
        ///目的IP：       (4bytes)发送端要梦实哪康蒙        
        ///目的端口号       (2bytes)
        ///是否转发         1是0否
        /// </summary>
        RemoteSecoud = 0x301F,
        RemoteSecoudACK = 0x3020,
        /// <summary>
        /// 连接验证密码.
        /// </summary>
        Remote3th = 0x300F,//连接验证密晟        
        Remote3thACK = 0x3010,

        /// <summary>
        /// 设置绑定面板空调目标
        /// </summary>
        SetACPanel = 0xE0E6,
        SetACPanelACK = 0xE0E7,

        /// <summary>
        /// 读取面板绑定的空调目标
        /// </summary>
        ReadACPanel = 0xE0E4,
        ReadACPanelACK = 0xE0E5,

        /// <summary>
        /// 读取面板音乐状态
        /// 发送无附加数据
        /// 回复3byte 
        /// 使能0：禁用；1启用
        /// 音乐模式（两种）这里固定1
        /// 区号，一个可以存储12个绑定目标从0开始，ON这里固定只做一个区号：0
        /// </summary>
        ReadMusicPanelEnable = 0x1930,
        ReadMusicPanelEnableACK = 0x1931,

        /// <summary>
        /// 配置音乐面板状态
        /// 发送 3byte 
        /// 使能0：禁用；1启用
        /// 音乐模式（两种）这里固定1 /// 区号，一个可以存储12个绑定目标从0开始，ON这里固定只做一个区号：0
        /// 回复1byte F8成功 F5失败
        /// </summary>
        SetMusicPanelEnable = 0x1932,
        SetMusicPanelEnableACK = 0x1933,

        /// <summary>
        /// 读取音乐面板配置目标
        /// 发送  分两次：0，1 ON只做一个区域，只发一次
        /// 回复26byte （回复状态，序号，12个目标）  F8/F5 0/1 子网号，设备号。子网号，设备号。子网号，设备号。。。
        /// </summary>
        ReadMusicPanelSetting = 0x1934,
        ReadMusicPanelSettingACK = 0x1935,

        /// <summary>
        /// 配置音乐面板配置目标
        /// 发送 25byte 序号 + 12个目标（子网号，设备号）
        /// 回复 F8/F5
        /// </summary>
        SetMusicPanelSetting = 0x1936,
        SetMusicPanelSettingACK = 0x1937,

        /// <summary>
        /// 读取干接点状态
        /// 0x15CE
        /// byte[2] =0 ==OFF（关、闭合） 干接点连接
        /// byte[2] =1 ==ON（开、断开） 干接点断开
        /// </summary>
        ReadDryContactStatus = 0x15CE,
        ReadDryContactStatusACK = 0x15CF,
        /// <summary>
        /// 广播干接点状态
        /// byte【2】=0 开
        /// byte【2】=1 关
        /// </summary>
        BroadcastDryContactStatus = 0x15D0,
        BroadcastDryContactStatusACK = 0x15D1,
        /// <summary>
        /// 修改干接点备注
        /// D220
        /// 22个byte 第一个byte干接点号,第二byte机械开关标志 0机械开关模式关状态 1表示机械开关模式开模式 ，非机械开关这里默认1 剩下20个byte是备注  操作码 D220
        /// </summary>
        SetDryContactRemark = 0xD220,
        SetDryContactRemarkACK = 0xD221,

        /// <summary>
        /// 红外控制命令
        /// DB90
        /// 1 通道号（发射口编号）
        /// 2 设备号（回路号，存放红外码的区域编号）
        /// 3 功能号
        /// 4 开关状态检测 1 = 检测
        /// 5 固定 0
        /// 6 随机数
        /// </summary>
        InfraredControl = 0xDB90,
        InfraredControlACK = 0xDB91,
        /// <summary>
        /// 上传红外码
        /// 137A
        /// </summary>
        UpLoadInfrared = 0x137A,
        UpLoadInfraredACK = 0x137B,

        /// <summary>
        /// 0x137C 下载红外模块回路数据0x
        /// 第一步：序号(1-25)＋包号(包号为0)（小包）
        /// ACK: 序号(1-25)＋包号(包号为0) + 设备码（1byte）+ 组码（2 byte）+ 红外数据总长度(1byte) + 
        /// 传送媒体（0：HDL-BUS，1：TCP/IP  UDP，2：KNX）(包号为0) + name[20]（小包）
        /// 第二步：序号(1-25)＋包号 (包号为1开始增加) （小包）
        /// ACK: 序号(1-25)＋包号(包号为1开始增加) + + 红外数据(nBYTE)
        /// 重复第二步，直至红外数据下载完毕!
        /// </summary>
        DownloadInfrared = 0x137C,
        DownloadInfraredACK = 0x137D,

        //ControlMusicModel1 = 0x192E,
        //ControlMusicModel1ACK = 0x192F,

        //ControlMusicModel2 = 0x1970,
        //ControlMusicModel2ACK = 0x1971,
        /// <summary>
        /// 0xE504
        /// 1   功能号 0 = 读取红外发射通道总数；1 = 读取通道备注；2=修改通道备注
        /// 2   通道号 1-N；F8表示读取通道总数
        /// 当功能号为0 或者1 时，请忽略下面相关数据；只有当功能号为2时，后面数据有意义，为备注
        /// 3   备注数据1byte   0 – FF
        /// 4   备注数据2byte   0 – FF
        /// 5   备注数据3byte   0 – FF
        /// 6   备注数据4byte   0 – FF
        /// 7   备注数据5byte   0 – FF
        /// 8   备注数据6byte   0 – FF
        /// 9   备注数据7byte   0 – FF
        /// 10  备注数据8byte   0 – FF
        /// 11  备注数据9byte   0 – FF
        /// 12  备注数据10byte  0 – FF
        /// 13  备注数据11byte  0 – FF
        /// 14  备注数据12byte  0 – FF
        /// 15  备注数据13byte  0 – FF
        /// 16  备注数据14byte  0 – FF
        /// 17  备注数据15byte  0 – FF
        /// 18  备注数据16byte  0 – FF
        /// 19  备注数据17byte  0 – FF
        /// 20  备注数据18byte  0 – FF
        /// 21  备注数据19byte  0 – FF
        /// 22  备注数据20byte  0 – FF
        /// </summary>
        InfraredChannelControl = 0xE504,
        InfraredChannelControlACK = 0xE505,

        /// <summary>
        /// 修改网关ip地址相关参数
        /// </summary>
        UpdateGatewayIp = 0xF039,
        UpdateGatewayIpACK = 0xF03A,

        /// <summary>
        /// 修改无线配置
        /// [0]control byte
        /// 
        ///bit0 255:GateNet本身   0～254 general note 之 GateNet
        ///[1]
        ///[2]
        ///[3]  
        ///[4]
        ///[5] 对应频段
        ///0((Chinese WPAN Band))  1(-European SRD Band)  2-(North_American ISM Band)
        ///[6]channel(Center Frequency) 
        ///((Chinese WPAN Band)): 0~12
        ///曜?780MHz,782,784,3-786MHz,
        ///（nonstandard）,用非标准请慎重4-770MHz 5-772MHz,6-774MHz,7-776MHz,8-778Mz,9-788MHz,10-790MHz,11-792MHz,12-794MHz    
        ///(European SRD Band)(0~12)
        ///曜?864MHz,1-866MHz,2-868MHz.3-870MHz
        ///（nonstandard）4-858MHz,5-860MHz,6-862MHz，7-872MHz,8-874MHz,9-876MHz,10-878MHz,11-880MHz,12-882MHz,
        ///(North_American ISM Band):（0~12）
        ///标准北美频段?0-904MHz,906,908,910,912,914,916,918,920,922,924,926,12-928MHz
        ///[7]~[22] SECURITY_KEY
        /// </summary>
        WriteManageWirelessNet = 0x1D36,
        WriteManageWirelessNetACK = 0x1D37,
        /// <summary>
        /// 尝试修改无线配置，如果成功则发上一条命令来进行修改
        /// </summary>
        TestWriteManageWirelessNet = 0x1d38,
        TestWriteManageWirelessNetACK = 0x1d39,

        /// <summary>
        /// 0x1976
        /// 读取面板配置地热信息
        /// </summary>
        ReadACFloorHeatingSettingEquipment = 0x1976,
        ReadACFloorHeatingSettingEquipmentACK = 0x1977,

        /// <summary>
        /// 1bytes loopid
        /// </summary>
        Read43FloorHeatingSettingEquipment = 0x1940,
        /// <summary>
        /// 4.3
        /// 1地热地冷开启关闭：0关,1开,           (0 - 1)  (1byte)     
        ///2地热地冷温度源SOURCE: 0本,1外,2两者平均    (0 - 2)  (1byte)
        ///3地热地冷外温度源1使能: (0关,1收广播,2读)20120928改      (0 - 2)  (1byte)    //用于正常外温度控制 
        ///4地热地冷外温度源1子网地址           (0-255)  (1byte)
        ///5地热地冷外温度源1设备地址           (0-255)  (1byte)
        ///6地热地冷外温度源1通道号             (0-255)   (1byte) 
        ///7地热地冷外温度源2使能: (0关,1收广播,2读)20120928改      (0 - 2)  (1byte)    //用于正常外温度控制 
        ///8地热地冷外温度源2子网地址           (0-255)  (1byte)
        ///9地热地冷外温度源2设备地址           (0-255)  (1byte)
        ///10地热地冷外温度源2通道号             (0-255)   (1byte)
        ///11地热最高温度源使能: (0关,1收广播,2读)20120928改     (0 - 2)  (1byte)  //测量最高限温度，用于限定控制
        ///12地热最高温度源子网地址          (0-255)  (1byte)
        ///13地热最高温度源设备地址          (0-255)  (1byte)
        ///14地热最高温度通道号              (0-255)   (1byte) 
        ///15地热地冷室外温度使能: (0关,1收广播,2读)20120928改       (0 - 2)  (1byte)   //测量室外温度，仅显示用
        ///16地热地冷室外温度子网地址            (0-255)  (1byte)
        ///17地热地冷室外温度设备地址            (0-255)  (1byte)
        ///18地热地冷室外温度通道号              (0-255)   (1byte)      
        ///19地热地冷PID使能：0:非PID, 1:PID(默认)        (0 - 1)                   (1byte)
        ///20地热地冷信号类型：0:Relay(默认),1:PWM Lavel     (0-1)                  (1byte)
        ///21地热地冷最小PWM:0%(默认), 0-100%(注意：最大PWM>=最小PWM)               (1byte)
        ///22地热地冷最大PWM:100%(默认),0-100%(注意：最大PWM>=最小PWM)              (1byte)       //20121206
        ///23地热地冷速度SPEED:lower,low,M(默认),high,higher     (0-4)  (1byte)
        ///24地热地冷周期CYCLE:1,2,3,5(默认),7,10,15,20分钟min         (0-7)  (1byte)
        ///25地热地冷工作温度模式种类设置   bit7:,6:,5:,4:时间,3:离开,2:夜晚,1:白天,0:普通--(0关1开)   (1byte)     
        ///26地热地冷锁定运行使能  0:关(默认),1:开        (0 - 1)       (1byte)
        ///27地热地冷时间1(白天)时       (0-23)  (1byte)
        ///28地热地冷时间1(白天)分       (0-59)  (1byte)
        ///29地热地冷时间2(夜晚)时       (0-23)  (1byte)
        ///30地热地冷时间2(夜晚)分       (0-59)  (1byte)
        ///31地热最高温度设定值:(摄氏5-80，华氏41-176)             (1byte)    
        ///32空                                                   (1byte)
        ///33地热地冷控制模式:0:命令控制(默认),   1:运算控制        (1byte)
        ///34地热地冷标志: 0地热，1地冷，2自动                      (1byte)        
        ///35地热地冷同步发送: 0不同步，1同步                     (1byte)       
        ///36地热地冷同步接收: bit0开关、bit1模式、bit2温度(bit值0不同步、bit值1同步)               (1byte) 
        ///37地热地冷自动模式触发温度偏移值：1-5                  (1byte)   //167、168、5001面板
        ///彩屏加入20150714
        ///38 地热地冷1子网ID(命令控制目标)：0-255               (1byte)
        ///39 地热地冷1设备ID(命令控制目标)：0-255               (1byte)       
        ///40 地热地冷1通道号(命令控制目标): 1-6(默认1)          (1byte)
        ///41 地热地冷设置温度范围低限，                         1byte    (摄氏5-35，华氏41-95)
        ///42 地热地冷设置温度范围高限,                          1byte    (摄氏5-35，华氏41-95)
        ///43 温度模式(摄氏Celsius:0(默认)，华氏Fahrenheit:1),   1byte     //此参数不保存，仅作为处理温度参数的依据
        ///44 地热页号0-8                                       (1byte  /// </summary>
        Read43FloorHeatingSettingEquipmentACK = 0x1941,

        SetACFloorHeatingSettingEquipment = 0x1978,
        SetACFloorHeatingSettingEquipmentACK = 0x1979,
        /// <summary>
        /// 4.3
        /// 1地热地冷开启关闭：0关,1开,           (0 - 1)  (1byte)     
        ///2地热地冷温度源SOURCE: 0本,1外,2两者平均    (0 - 2)  (1byte)
        ///3地热地冷外温度源1使能: (0关,1收广播,2读)20120928改      (0 - 2)  (1byte)    //用于正常外温度控制 
        ///4地热地冷外温度源1子网地址           (0-255)  (1byte)
        ///5地热地冷外温度源1设备地址           (0-255)  (1byte)
        ///6地热地冷外温度源1通道号             (0-255)   (1byte) 
        ///7地热地冷外温度源2使能: (0关,1收广播,2读)20120928改      (0 - 2)  (1byte)    //用于正常外温度控制 
        ///8地热地冷外温度源2子网地址           (0-255)  (1byte)
        ///9地热地冷外温度源2设备地址           (0-255)  (1byte)
        ///10地热地冷外温度源2通道号             (0-255)   (1byte)
        ///11地热最高温度源使能: (0关,1收广播,2读)20120928改     (0 - 2)  (1byte)  //测量最高限温度，用于限定控制
        ///12地热最高温度源子网地址          (0-255)  (1byte)
        ///13地热最高温度源设备地址          (0-255)  (1byte)
        ///14地热最高温度通道号              (0-255)   (1byte) 
        ///15地热地冷室外温度使能: (0关,1收广播,2读)20120928改       (0 - 2)  (1byte)   //测量室外温度，仅显示用
        ///16地热地冷室外温度子网地址            (0-255)  (1byte)
        ///17地热地冷室外温度设备地址            (0-255)  (1byte)
        ///18地热地冷室外温度通道号              (0-255)   (1byte)      
        ///19地热地冷PID使能：0:非PID, 1:PID(默认)        (0 - 1)                   (1byte)
        ///20地热地冷信号类型：0:Relay(默认),1:PWM Lavel     (0-1)                  (1byte)
        ///21地热地冷最小PWM:0%(默认), 0-100%(注意：最大PWM>=最小PWM)               (1byte)
        ///22地热地冷最大PWM:100%(默认),0-100%(注意：最大PWM>=最小PWM)              (1byte)       //20121206
        ///23地热地冷速度SPEED:lower,low,M(默认),high,higher     (0-4)  (1byte)
        ///24地热地冷周期CYCLE:1,2,3,5(默认),7,10,15,20分钟min         (0-7)  (1byte)
        ///25地热地冷工作温度模式种类设置   bit7:,6:,5:,4:时间,3:离开,2:夜晚,1:白天,0:普通--(0关1开)   (1byte)     
        ///26地热地冷锁定运行使能  0:关(默认),1:开        (0 - 1)       (1byte)
        ///27地热地冷时间1(白天)时       (0-23)  (1byte)
        ///28地热地冷时间1(白天)分       (0-59)  (1byte)
        ///29地热地冷时间2(夜晚)时       (0-23)  (1byte)
        ///30地热地冷时间2(夜晚)分       (0-59)  (1byte)
        ///31地热最高温度设定值:(摄氏5-80，华氏41-176)             (1byte)    
        ///32空                                                   (1byte)
        ///33地热地冷控制模式:0:命令控制(默认),   1:运算控制        (1byte)
        ///34地热地冷标志: 0地热，1地冷，2自动                      (1byte)        
        ///35地热地冷同步发送: 0不同步，1同步                     (1byte)       
        ///36地热地冷同步接收: bit0开关、bit1模式、bit2温度(bit值0不同步、bit值1同步)               (1byte) 
        ///37地热地冷自动模式触发温度偏移值：1-5                  (1byte)   //167、168、5001面板
        ///彩屏加入20150714
        ///38 地热地冷1子网ID(命令控制目标)：0-255               (1byte)
        ///39 地热地冷1设备ID(命令控制目标)：0-255               (1byte)       
        ///40 地热地冷1通道号(命令控制目标): 1-6(默认1)          (1byte)
        ///41 地热地冷设置温度范围低限，                         1byte    (摄氏5-35，华氏41-95)
        ///42 地热地冷设置温度范围高限,                          1byte    (摄氏5-35，华氏41-95)
        ///43 温度模式(摄氏Celsius:0(默认)，华氏Fahrenheit:1),   1byte     //此参数不保存，仅作为处理温度参数的依据
        ///44 地热页号0-8                                       (1byte  /// </summary>
        Set43FloorHeatingSettingEquipment = 0x1942,
        /// <summary>
        /// 1bytes loopid
        /// </summary>
        Set43FloorHeatingSettingEquipmentACK = 0x1943,


        #region ============================面板空调综合参数设置命令=======================================//彩屏
        /// <summary>
        ///[0]//空调页号(0-8)   
        /// </summary>
        READ_AIR_ALL_Parameter = 0x19AA,
        ///[0]//空调页号(0-8)                                  1byte
        ///[1]//空调功能(0关闭,1开启(默认))                     1byte
        ///[2]//目标子网ID(0-255)                              1byte
        ///[3]//目标设备ID(0-255)                              1byte
        ///[4]//空调号(1(默认)-128)                            1byte       
        ///[5]//空调控制命令选择(0旧(默认),1新)                 1byte 
        ///[6]//空调运算控制使能(0禁止-1允许(默认))             1byte
        ///[7]//空调上电开关状态(0关，1(默认)保持上次状态)       1byte 
        ///[8]//红外运算控制使能(0禁止(默认)-1允许)             1byte   弃用     
        ///[9]//空调红外控制使能      (0禁止(默认)-1允许)       1byte   弃用   
        ///[10]//空调红外上电控制使能 (0禁止-1允许(默认))       1byte   弃用  
        ///[11]//扫风功能(0关闭(默认),1开启)                   1byte
        ///[12]//风机节能标志(0不省电(默认),1省电)               1byte
        ///风速模式种类
        ///[13]//风速种类大小-speed_size,                     1byte    (风速种类:0 自动，1高风，2中风，3低风)           
        ///[14]//风速种类存储器1-speed1,                      1byte
        ///[15]//风速种类存储器2-speed2,                      1byte      
        ///[16]//风速种类存储器3-speed3,                      1byte
        ///[17]//风速种类存储器4-speed4,                      1byte          
        ///[18]//模式种类大小-Mode_size,                      1byte    (模式种类:0 制冷，1制热，2通风，3自动，4除湿)
        ///[19]//模式种类存储器1-Mode1,                       1byte
        ///[20]//模式种类存储器2-Mode2,                       1byte      
        ///[21]//模式种类存储器3-Mode3,                       1byte
        ///[22]//模式种类存储器4-Mode4,                       1byte
        ///[23]//模式种类存储器5-Mode5,                       1byte
        ///设置温度范围
        ///[24]//制冷设置温度范围低限set cool low，            1byte    (摄氏0-30，华氏32-86)
        ///[25]//制冷设置温度范围高限set cool high,            1byte        
        ///[26]//制热设置温度范围低限set heat low，            1byte    (摄氏0-30，华氏32-86)
        ///[27]//制热设置温度范围高限set heat high,            1byte       
        ///[28]//自动设置温度范围低限set auto low，            1byte    (摄氏0-30，华氏32-86)
        ///[29]//自动设置温度范围高限set auto high,            1byte   
        ///[30]//除湿设置温度范围低限set dry low，             1byte    (摄氏0-30，华氏32-86)
        ///[31]//除湿设置温度范围高限set dry high,             1byte   
        ///[32]//空调温度源: 0本机,1外部,2两者平均             (1byte)
        ///[33]//空调外温度源1使能: (0关,1收广播,2读)          (1byte)    
        ///[34]//空调外温度源1子网地址           (0-255)       (1byte)
        ///[35]//空调外温度源1设备地址           (0-255)       (1byte)
        ///[36]//空调外温度源1通道号             (0-255)       (1byte) 
        ///[37]//空调外温度源2使能: (0关,1收广播,2读) 
        ///[38]//空调外温度源2子网地址           (0-255)       (1byte)
        ///[39]//空调外温度源2设备地址           (0-255)       (1byte)
        ///[40]//空调外温度源2通道号            (0-255)        (1byte)
        ///[41]//温度模式(摄氏Celsius:0(默认)，华氏Fahrenheit:1),   1byte   //此参数不保存，仅作为处理温度参数的依据
        READ_AIR_ALL_Parameter_ack = 0x19AB,

        /// <summary>
        /// [0]//空调页号(0-8)                                  1byte
        ///[1]//空调功能(0关闭,1开启(默认))                     1byte
        ///[2]//目标子网ID(0-255)                              1byte
        ///[3]//目标设备ID(0-255)                              1byte
        ///[4]//空调号(1(默认)-128)                            1byte       
        ///[5]//空调控制命令选择(0旧(默认),1新)                 1byte 
        ///[6]//空调运算控制使能(0禁止-1允许(默认))             1byte
        ///[7]//空调上电开关状态(0关，1(默认)保持上次状态)       1byte 
        ///[8]//红外运算控制使能(0禁止(默认)-1允许)             1byte   弃用     
        ///[9]//空调红外控制使能      (0禁止(默认)-1允许)       1byte   弃用   
        ///[10]//空调红外上电控制使能 (0禁止-1允许(默认))       1byte   弃用  
        ///[11]//扫风功能(0关闭(默认),1开启)                   1byte
        ///[12]//风机节能标志(0不省电(默认),1省电)               1byte
        ///风速模式种类
        ///[13]//风速种类大小-speed_size,                     1byte    (风速种类:0 自动，1高风，2中风，3低风)           
        ///[14]//风速种类存储器1-speed1,                      1byte
        ///[15]//风速种类存储器2-speed2,                      1byte      
        ///[16]//风速种类存储器3-speed3,                      1byte
        ///[17]//风速种类存储器4-speed4,                      1byte          
        ///[18]//模式种类大小-Mode_size,                      1byte    (模式种类:0 制冷，1制热，2通风，3自动，4除湿)
        ///[19]//模式种类存储器1-Mode1,                       1byte
        ///[20]//模式种类存储器2-Mode2,                       1byte      
        ///[21]//模式种类存储器3-Mode3,                       1byte
        ///[22]//模式种类存储器4-Mode4,                       1byte
        ///[23]//模式种类存储器5-Mode5,                       1byte
        ///设置温度范围
        ///[24]//制冷设置温度范围低限set cool low，            1byte    (摄氏0-30，华氏32-86)
        ///[25]//制冷设置温度范围高限set cool high,            1byte        
        ///[26]//制热设置温度范围低限set heat low，            1byte    (摄氏0-30，华氏32-86)
        ///[27]//制热设置温度范围高限set heat high,            1byte       
        ///[28]//自动设置温度范围低限set auto low，            1byte    (摄氏0-30，华氏32-86)
        ///[29]//自动设置温度范围高限set auto high,            1byte   
        ///[30]//除湿设置温度范围低限set dry low，             1byte    (摄氏0-30，华氏32-86)
        ///[31]//除湿设置温度范围高限set dry high,             1byte   
        ///[32]//空调温度源: 0本机,1外部,2两者平均             (1byte)
        ///[33]//空调外温度源1使能: (0关,1收广播,2读)          (1byte)    
        ///[34]//空调外温度源1子网地址           (0-255)       (1byte)
        ///[35]//空调外温度源1设备地址           (0-255)       (1byte)
        ///[36]//空调外温度源1通道号             (0-255)       (1byte) 
        ///[37]//空调外温度源2使能: (0关,1收广播,2读) 
        ///[38]//空调外温度源2子网地址           (0-255)       (1byte)
        ///[39]//空调外温度源2设备地址           (0-255)       (1byte)
        ///[40]//空调外温度源2通道号            (0-255)        (1byte)
        ///[41]//温度模式(摄氏Celsius:0(默认)，华氏Fahrenheit:1),   1byte   //此参数不保存，仅作为处理温度参数的依据   
        /// </summary>
        Set_AIR_ALL_Parameter = 0x19AC,

        ///[0]//空调页号(0-8) 1byte
        Set_AIR_ALL_Parameter_ack = 0x19AD,
        #endregion


        /// <summary>
        /// 0X1d12
        /// 读取地热温度探头
        /// 无附加数据
        /// 回复
        /// [0]unit 单位0：摄氏   1：华氏
        /// [1]总线上18B20总根数
        /// [2]总线上正常工作18B20的根数
        /// [3]总线上不正常工作18B20的根数
        /// </summary>
        ReadFloorHeatProbe = 0x1D12,
        ReadFloorHeatProbeACK = 0x1D13,

        /// <summary>
        /// 0x1C54
        /// 配置地热温度传感器
        /// 附加数据：
        /// [0]number(1-6) 地热号
        /// [1]operation model      0 -- self_op    1 -- panel_op    //这个字节不允许扩展   
        /// [2]temperature_source   0 -- 自带18B20  1--总线温度(1路)  2--两者取平均值 
        /// [3]保留 
        /// [4]sensor1 subid           
        /// [5]sensor1 device id
        /// [6]sensor1 channel (1~10) 
        /// [7]MaxT_Type   BIT:0-- 通过自带18B20  1--通过网络温度(1路) BIT7:0--除能最高温度检测 1:使能最高温度检测
        /// [8]MaxT_SensorNumber 此地热号对应传感器的编号   0~还没编号  1~250已经编号的号码 
        /// [9]MaxT_sub_ID           
        /// [10]MaxT_device_ID
        /// [11]sensor2 channel (1~10) 
        /// [12]Max_Temperarture 根据通道温度类型判别是摄氏还是华氏     BIT7:1-温度广播，0-no  
        /// [13]多个传感器取平均值 使能  bit0:1st18b20 bit1:2st18b20  bit2:3st18b20  bit3:4st18b20  
        /// [14]运算用Sensor_Number1
        /// [15]运算用Sensor_Number2
        /// [16]运算用Sensor_Number3
        /// [17]运算用Sensor_Number4 
        /// 回复 2byte 
        /// 成功或者失败
        /// 回路号
        /// </summary>
        WriteFloorHeatSensor = 0x1C54,
        WriteFloorHeatSensorACK = 0x1C54,

        /// <summary>
        /// 0x1D56
        /// 读取地热温度传感器
        /// 附加数据：回路号
        /// 回复
        /// [0]number(1-6) 地热号
        /// [1]operation model      0 -- self_op    1 -- panel_op    //这个字节不允许扩展   
        /// [2]temperature_source   0 -- 自带18B20  1--总线温度(1路)  2--两者取平均值 
        /// [3]保留 
        /// [4]sensor1 subid           
        /// [5]sensor1 device id
        /// [6]sensor1 channel (1~10) 
        /// [7]MaxT_Type   BIT:0-- 通过自带18B20  1--通过网络温度(1路) BIT7:0--除能最高温度检测 1:使能最高温度检测
        /// [8]MaxT_SensorNumber 此地热号对应传感器的编号   0~还没编号  1~250已经编号的号码 
        /// [9]MaxT_sub_ID           
        /// [10]MaxT_device_ID
        /// [11]sensor2 channel (1~10) 
        /// [12]Max_Temperarture 根据通道温度类型判别是摄氏还是华氏     BIT7:1-温度广播，0-no  
        /// [13]多个传感器取平均值 使能  bit0:1st18b20 bit1:2st18b20  bit2:3st18b20  bit3:4st18b20  
        /// [14]运算用Sensor_Number1
        /// [15]运算用Sensor_Number2
        /// [16]运算用Sensor_Number3
        /// [17]运算用Sensor_Number4      
        /// </summary>
        ReadFloorHeatSensor = 0x1C56,
        ReadFloorHeatSensorACK = 0x1C57,

        /// <summary>
        /// 0x1D16
        /// 读取地热温度传感器数据
        /// 附加数据：编号（1-13）1D12读取总数，最多13跟
        /// 回复
        /// [0]num编号    1~13
        /// [1~8]ROM,物理地址
        /// [9]状态值   0：正常    1：不正常    2：新增加
        /// [10]Compensation       (5~15)温度补偿    对照：(5,10,15)= -5,0,5 
        /// [11]~[30]DS18B20Remark
        /// [31]ID编号 （只需要这个byte）
        /// [32]温度值   BIT7表示符号 0：表示正数  1：表示负数
        /// </summary>
        ReadFloorHeatProbeNumber = 0x1D16,
        ReadFloorHeatProbeNumberACK = 0x1D17,

        ControlMusicModel = 0x192E,
        ControlMusicModel1ACK = 0x192F,

        ControlMusicModel2 = 0x1970,
        ControlMusicModel2ACK = 0x1971,

        ///0xE45C  设置逻辑模块（RGB）颜色
        ///1 逻辑回路号 
        ///2 整体亮度
        ///3 颜色号 固定为 254
        ///4 运行时间 高位
        ///5 运行时间 低位
        ///6 逻辑灯类型 1-5//1单路 2CCT 3RGB 4RGBW 5RGBWY
        ///7 逻辑回路 通道1的值 //RGB最大值是255 其它类为最大为100
        ///8 逻辑回路 通道2的值 //RGB最大值是255 其它类为最大为100
        ///9 逻辑回路 通道3的值 //RGB最大值是255 其它类为最大为100
        ///10 逻辑回路 通道4的值 //RGB最大值是255 其它类为最大为100
        ///11 逻辑回路 通道5的值 //RGB最大值是255 其它类为最大为100
        SetLogicLoopColor = 0xE45C,
        ///1 逻辑回路号 
        ///2 整体亮度
        ///3 颜色号 固定为 254
        ///4 运行时氵高位
        ///5 运行时间 低位
        ///6 逻辑灯类型 1-5//1单路 2CCT 3RGB 4RGBW 5RGBWY
        ///7 逻辑回路 通道1的值 //RGB最大值是255 其它类为最大为100
        ///8 逻辑回路 通道2的值 //RGB最大值是255 其它类为最大为100
        ///9 逻辑回路 通道3的值 //RGB最大值是255
        ///10 逻辑回路 通道4的值 //RGB最大值是255 其它类为最大为100
        ///11 逻辑回路 通道5的值 //RGB最大值是255 其它类为最大为100
        SetLogicLoopColorACK = 0xE45D,

        ///0xE472 读取逻辑模块（RGB）颜色信息
        ///1 逻辑回路号 
        ReadLogicLoopColor = 0xE472,
        ///1 逻辑回路号 
        ///2 整体亮度
        ///3 颜色号 固定为 254
        ///4 运行时间 高位
        ///5 运行时间 低位
        ///6 逻辑灯类型 1-5//1单路 2CCT 3RGB 4RGBW 5RGBWY
        ///7 逻辑回路 通道1的值 //RGB最大值是255 其它类为最大为100
        ///8 逻辑回路 通道2的值 //RGB最大值是255 其它类为最大为100
        ///9 逻辑回路 通道3的值 //RGB最大值是255 其它类为最大为100
        ///10 逻辑回路 通道4的值 //RGB最大值是255 其它类为最大为100
        ///11 逻辑回路 通道5的值 //RGB最大值是255 其它类为最大为100
        ReadLogicLoopColorACK = 0xE473,



        /// <summary>
        /// 读取门锁时钟命令 0x1F48
        /// 读取门锁时钟命令回复  0x1F49 
        /// 1门锁编号 
        ///2年，公元年份与2000的差（0-100 / 失败 0xF5）                                  
        ///3月 (1-12)    
        ///4日(1-31)    
        ///5时(0-23)
        ///6分（0-59)                                                                                   
        ///7秒(0-59)
        /// </summary>
        ReadDoorLockClock = 0xDA00,
        ReadDoorLockClockACK = 0xDA01,

        /// <summary>
        /// 设置门锁时间 0xDA02 
        ///1年，公元年份与2000的差（0-100 / 失败 0xF5）                                  
        ///2月 (1-12)    
        ///3日(1-31)    
        ///4时(0-23)
        ///5分（0-59)                                                                                           
        ///6秒(0-59)
        /// 星期(0-6，0是星期日)
        /// 设置门锁时间回复 0xDA03 
        /// 1成功或者失败 （F8= 成功； F5 = 失败）
        /// </summary>
        SetDoorLockTime = 0xDA02,
        SetDoorLockTimeACK = 0xDA03,

        /// <summary>
        /// 读取门锁状态和报警 0x1F4B  
        /// 1门锁编号
        /// 2 信息序号，数字越小越新(0 ~ 99 / 100 : 全读)
        ///  读取门锁状态和报警回复 0x1F4C
        /// 1门锁编号
        /// 2 信息序号，数字越小越新(0 ~ 99 / 0xf5 : 失败)
        ///3 类型  （开锁:  0x01 指纹开锁；0x02 密码开锁; 0x03 感应卡开锁;0x04 机械钥匙开锁;0x05 远程授权开锁;0x06 临时密码开锁;
        /// 报警:0x07 使用机械钥匙开锁;0x08 密码验证错误报警（密码连续3次次错误）;0x09  ：门未锁好报警（门锁未关好， 当门锁好时上报解除报警）;0x0a:劫持报警（输入防劫持密码或者防劫持指纹开锁时报警）;0x0b 防撬报警（门锁被撬开时报警）;0x0c 电量不足报警（电量不足时报警）;0x0d  ：指纹验证错误报警（开门验证输入指纹连续错误次数达到门锁规定3次时报警); 0x0e 卡片验证错误报警（开门验证输入卡片连续错误次数达到门锁规定3次报警）
        ///4用户ID(0 ~ 99 / 密码 0 ~ 9 / 临时密码固定为 10)    
        ///5 年，公元年份与2000的差（0-100 / 失败 0xF5）                                  
        ///6 月 (1-12)    
        ///7 日(1-31)    
        ///8 时(0-23)
        ///9 分（0-59)  
        ///10  秒(0-59)                                                                                        
        /// </summary>
        ReadDoorLockStateAndAlarm = 0x1F4B,
        ReadDoorLockStateAndAlarmACK = 0x1F4C,

        /// <summary>
        /// 广播门锁状态和报警 0x1F4D  
        /// 1 门锁编号
        /// 2 信息序号，数字越小越新(0 ~ 99 / 0xf5 : 失败)
        /// 3 类型  （开锁:  
        /// 0x01     指纹开锁；
        /// 0x02     密码开锁        
        /// 0x03   感应卡开锁        
        /// 0x04 机械钥匙开锁        
        /// 0x05 远程授权开锁        
        /// 0x06 临时密码开锁        
        ///报警:        
        /// 0x07  ：使用机械钥匙开锁        
        ///0x08  ：密码验证错误报警（密码连续3次次错误）        
        ///0x09  ：门未锁好报警（门锁未关好， 当门锁好时上报解除报警）        
        ///0x0a  ：劫持报警（输入防劫持密码或者防劫持指纹开锁时报警）        
        ///0x0b  ：防撬报警（门锁被撬开时报警）        
        ///0x0c  ：电量不足报警（电量不足时报警）        
        ///0x0d  ：指纹验证错误报警（开门验证输入指纹连续错误次数达到门锁规定3次时报警）        
        ///0x0e  ：卡片验证错误报警（开门验证输入卡片连续错误次数达到门锁规定3次报警）
        ///4 用户ID(0 ~ 99 / 密码 0 ~ 9 / 临时密码固定为 10)    
        ///5 年，公元年份与2000的差（0-100 / 失败 0xF5）                                  
        ///6 月 (1-12)    
        ///7 日(1-31)    
        ///8 时(0-23)
        ///9 分（0-59)  
        ///10  秒(0-59)                                                                                        
        /// </summary>
        BroadcastDoorLockStateAndAlarm = 0x1F4D,

        /// <summary>
        /// 读取门锁用户备注 0x1F4E  
        /// 1 门锁编号
        /// 2 开锁类型 (0x01 :指纹；0x02:密码;0x03:感应卡;0x04:感应卡)
        /// 3 用户ID(0 ~ 99 / 密码 0 ~ 9 / 临时密码固定为 10)  
        ///  读取门锁用户备注回复 0x1F4F
        /// 1 门锁编号
        /// 2 密钥类型 (0x01 :指纹；0x02:密码;0x03:感应卡;0x04:感应卡；0x05:失败  )
        ///3 用户ID(0 ~ 99 / 密码 0 ~ 9 / 临时密码固定为 10)    
        ///4～23 （用户备注0～19，用户备注的值都是0～255）                                
        /// </summary>
        ReadDoorLockUseRemark = 0x1F4E,
        ReadDoorLockUseRemarkACK = 0x1F4F,


        /// <summary>
        /// 设置门锁用户备注 0x1F50  
        /// 1 门锁编号
        /// 2 开锁类型 (0x01 :指纹；0x02:密码;0x03:感应卡;0x04:感应卡；)
        /// 3 用户ID(0 ~ 99 / 密码 0 ~ 9 / 临时密码固定为 10)  
        /// 4～23 （用户备注0～19，用户备注的值都是0～255）  
        /// 设置门锁用户备注回复 0x1F51
        /// 1 成功或者失败（F8 = 成功；F5 ＝ 失败）
        /// </summary>
        SetDoorLockUseRemark = 0x1F50,
        SetDoorLockUseRemarkACK = 0x1F51,

        /// <summary>
        /// 读取临时密码配置 0x1F52  
        /// 1 门锁编号
        /// 读取临时密码配置回复 0x1F53
        /// 1 门锁编号
        /// 2 enable (0:unable/1:enable /失败 0xF5)
        /// 3 可用次数 （0～15）
        /// 5 Bit15-Bit0 密码有效时间（分钟） （值为65532）
        /// 6～11 密码1～密码6 （值为（0～9）
        /// </summary>
        ReadTemporaryPasswordConfigure = 0x1F52,
        ReadTemporaryPasswordConfigureACK = 0x1F53,

        /// <summary>
        /// 设置临时密码 0x1F54  
        /// 1 门锁编号
        /// 2 enable (0:unable/1:enable /失败 0xF5)
        /// 3 可用次数 （0～15）
        /// 5 Bit15-Bit0 密码有效时间（分钟） （值为65532）
        /// 6～11 密码1～密码6 （值为（0～9）
        /// 设置临时密码回复 0x1F53
        /// 1 成功或者失败（F8 = 成功；F5 ＝ 失败）
        /// </summary>
        SetTemporaryPassword = 0x1F54,
        SetTemporaryPasswordACK = 0x1F55,

        /// <summary>
        /// 远程开关锁 0x1F56  
        /// 1 门锁编号
        /// 2 开关状态 (1:开/2:关 )
        /// 远程开关锁回复 0x1F57
        /// 1 成功或者失败（F8 = 成功；F5 ＝ 失败）
        /// </summary>
        RemoteOpenOrCloseDoorLock = 0x1F56,
        RemoteOpenOrCloseDoorLockACK = 0x1F57,

        RemoteReadDoorLockPassword = 0x1FE0,
        RemoteReadDoorLockPasswordACK = 0x1FE1,

        /// <summary>
        /// 读取开锁场景联动条件目标 0x1F58  
        /// 1 门锁编号
        /// 2 场景类型 (1:开锁/2:报警 )
        ///3 场景  报警和开锁只有一有效
        /// （开锁:  0x01 指纹开锁；0x02 密码开锁; 0x03 感应卡开锁;0x04 远程授权开锁;0x05 临时密码开锁;
        /// 报警:0x01 挟持报警; 0x02 ：门未锁好报警;0x03:电量低报警;0x04（感应卡，指纹，密码）错误报警;0x05 机械钥匙开门 报警;0x06 ：防撬报警
        ///4用户ID(0 ~ 99 / 密码 0 ~ 10（只有开锁场景有效）)  
        /// 5目标序号 (number0~19)
        /// 读取开锁场景联动条件目标回复 0x1F59
        /// 1 门锁编号
        /// 2 场景类型 (1:开锁/2:报警 / 0 无效 / 0xf5 失败)
        ///3 场景  报警和开锁只有一有效
        /// （开锁:  0x01 指纹开锁；0x02 密码开锁; 0x03 感应卡开锁;0x04 远程授权开锁;0x05 临时密码开锁;
        /// 报警:0x01 挟持报警; 0x02 ：门未锁好报警;0x03:电量低报警;0x04（感应卡，指纹，密码）错误报警;0x05 机械钥匙开门 报警;0x06 ：防撬报警
        ///4用户ID(0 ~ 99 / 密码 0 ~ 10(只有开锁场景有效))  
        /// 5目标序号 (number0~19)
        /// 6 Control_kind
        /// 7 Control_sub_net
        /// 8 Control_dev
        /// 9 Control_fenqu
        /// 10 Control_changjing          
        /// 11 Control_minute—singal_adj
        /// 12 Control_second—singal_adj 
        /// </summary>
        ReadDoorLockSceneObj = 0x1F58,
        ReadDoorLockSceneObjACK = 0x1F59,

        /// <summary>
        /// 设置开锁场景联动条件目标 0x1F5A 
        /// 1 门锁编号
        /// 2 场景类型 (1:开锁/2:报警 /:0无效)
        ///3 场景  报警和开锁只有一有效
        /// （开锁:  0x01 指纹开锁；0x02 密码开锁; 0x03 感应卡开锁;0x04 远程授权开锁;0x05 临时密码开锁;
        /// 报警:0x01 挟持报警; 0x02 ：门未锁好报警;0x03:电量低报警;0x04（感应卡，指纹，密码）错误报警;0x05 机械钥匙开门 报警;0x06 ：防撬报警
        ///4用户ID(0 ~ 99 / 密码 0 ~ 9（只有开锁场景有效）)  
        /// 5目标序号 (number0~19)
        /// /// 6 Control_kind
        /// 7 Control_sub_net
        /// 8 Control_dev
        /// 9 Control_fenqu
        /// 10 Control_changjing          
        /// 11 Control_minute—singal_adj
        /// 12 Control_second—singal_adj 
        /// 设置开锁场景联动条件目标回复 0x1F5B
        /// 1 成功或者失败（F8 = 成功；F5 ＝ 失败）
        /// 2 门锁编号
        /// 3 场景类型 (1:开锁/2:报警 /:0无效)
        ///4 场景  报警和开锁只有一有效
        /// （开锁:  0x01 指纹开锁；0x02 密码开锁; 0x03 感应卡开锁;0x04 远程授权开锁;0x05 临时密码开锁;
        /// 报警:0x01 挟持报警; 0x02 ：门未锁好报警;0x03:电量低报警;0x04（感应卡，指纹，密码）错误报警;0x05 机械钥匙开门 报警;0x06 ：防撬报警
        ///5用户ID(0 ~ 99 / 密码 0 ~ 10(只有开锁场景有效))  
        /// </summary>
        SetDoorLockSceneObj = 0x1F5A,
        SetDoorLockSceneObjACK = 0x1F5B,

        /// <summary>
        /// 创建连接
        /// </summary>
        CreatConnection = 0xE4EE,
        /// <summary>
        /// 创建连接返回(收到命令立刻返回)
        /// </summary>
        CreatConnectionACK = 0xE4EF,

        /// <summary>
        /// 连接成功后发送命令发送加密指令(收到命令立刻返回)
        /// </summary>
        SendEncryptionAfterConnected = 0xE4F0,

        /// <summary>
        ///  连接成功后发送命令请求加密指令((收到命令立刻返回)
        /// </summary>
        SendEncryptionAfterConnectedACK = 0xE4F1,

        /// <summary>
        /// GPRS控制
        /// </summary>
        GPRSControl = 0xE3D4,
        /// <summary>
        /// 消防模块 Security Module 011E
        /// </summary>
        SecurityModule = 0x011E,

        /// <summary>
        /// 音乐播放 Music Control 0218
        /// </summary>
        MusicControl = 0x0218,
        /// <summary>
        /// 逻辑灯调节 Logic Light Adjust 
        /// </summary>
        LogicLightAdjust = 0xE45E,


        /// <summary>
        /// 读已经存储进flash里面的记录
        /// 开始年     1  btye
        /// 开始月     1  btye
        /// 开始日     1  btye
        /// 结束年     1  btye
        /// 结束月     1  btye
        /// 结束日     1  btye
        /// </summary>
        RED_HSFH_TOTAL = 0x0138,
        /// <summary>
        /// 记录总数    2  btyes
        /// 开始地址    2  btyes
        /// </summary>
        RED_HSFH_TOTAL_ACK = 0x0139,

        /// <summary>
        /// 记录地址    (10 Bytes)
        /// Sart_Year，Sart_Mounch，Sart_Day，End_Year，End_Mounch，End_Day,History_Sart_Addr_H, History_Sart_Addr_L，History_Num_H, History_Num_L
        /// </summary>
        RED_HSFH_INFORMATION = 0x013a,
        /// <summary>
        /// 成功标志0xf8    1  btye
        ///    31 btyes 
        /// 第0字节为设警/报警区域，
        /// 第1字节为发生年，
        /// 第2字节为发生月，
        /// 第3字节为发生日，
        /// 第4字节为发生小时，
        /// 第5字节为发生分钟，
        /// 第6字节为发生秒钟，
        /// 第7字节为触发子网地址，
        /// 第8字节为触发设备地址，
        /// 第9字节为设防模式/报警类型高位，
        /// 第10字节为0/报警类型低位（1～19），
        /// 第11～31字节为触发设备备注
        /// </summary>
        RED_HSFH_INFORMATION_ACK = 0x013b,

        /// <summary>
        /// 暂时还没有存储进flash，但已经有报警记录的，读RAM的记录
        /// 开始年     1  btye
        /// 开始月     1  btye
        /// 开始日     1  btye
        /// 结束年     1  btye
        /// 结束月     1  btye
        /// 结束日     1  btye
        /// </summary>
        RED_HSRM_TOTAL = 0x0174,
        /// <summary>
        /// T记录总数   2  btyes
        /// 开始地址    2  btyes
        /// 结束地址    2  btyes
        /// </summary>
        RED_HSRM_TOTAL_ACK = 0x0175,

        /// <summary>
        /// 记录地址        2  btyes
        /// </summary>
        RED_HSRM_INFORMATION = 0x0176,

        /// <summary>
        /// 成功标志0xf8    1  btye
        /// 记录地址        2  btyes
        /// 记录信息        31 btyes
        /// </summary>
        RED_HSRM_INFORMATION_ACK = 0x0177,

        //记录信息注释：区号（1～8），年，月，日，小时，分钟，秒钟，子网id，设备id，报警类型，通道号，20 bytes备注信息 
        /// <summary>
        /// 清历史纪录
        /// 标志（0xf8）        1  btye
        /// </summary>
        CLEAR_SYSTEM_HISTORY = 0x014a,
        /// <summary>
        /// 返回标志（0xf8/0xf5）     1  btye
        /// </summary>
        CLEAR_SYSTEM_HISTORY_ACK = 0x014b,

        /// <summary>
        /// 读取安防传感器状态
        /// 区号 + 通道号 + 备注有效（1：备注 ，其他值无备注）
        /// </summary>
        ReadSecurityStatus = 0x15E4,
        /// <summary>
        /// 区号  通道号 状态(0:闭合 1:断开 2:不在线)  Bypass(0:不使能  1:使能)  备注
        /// </summary>
        ReadSecurityStatusACK = 0x15E5,

        /// <summary>
        /// 设置安防 BYPASS
        /// 区号  通道号 Bypass
        /// </summary>
        SetSecurityByPass = 0x15E0,
        SetSecurityByPassACK = 0x15E1,

    }

}
